/*
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   $Header:$
*/
package nesting.chooseairport;

import java.io.Serializable;
import java.util.Iterator;
import java.util.ArrayList;

import org.apache.beehive.netui.pageflow.PageFlowController;
import org.apache.beehive.netui.pageflow.Forward;
import org.apache.beehive.netui.pageflow.annotations.Jpf;

@Jpf.Controller(
    nested=true,
    simpleActions={
        @Jpf.SimpleAction(name="begin", path="findairport.jsp"),

        // This action returns to the original page flow, and raises the "chooseAirportCancelled"
        // action.  It is run when the user presses the Cancel button on findairport.jsp or on
        // confirm.jsp.
        @Jpf.SimpleAction(name="cancelSearch", returnAction="chooseAirportCancelled"),

        // This action runs when the user presses the OK button on confirm.jsp.  It returns to the
        // nesting page flow, where it raises the "chooseAirportDone" action.
        @Jpf.SimpleAction(
            name="confirmResults",
            returnAction="chooseAirportDone",
            outputFormBean="_currentResults"
        )
    },
    messageBundles={
        @Jpf.MessageBundle(bundlePath="org.apache.beehive.samples.netui.resources.nesting.chooseairport")
    }
)
public class ChooseAirport extends PageFlowController
{
    /**
     * This is the bean that will be returned to the original page flow.
     */
    private Results _currentResults;

    public Results getCurrentResults()
    {
        return _currentResults;
    }

    /**
     * This action runs when the user presses the Search button on findairport.jsp.  It chooses
     * an airport and forwards to the confirmation page.
     */
    @Jpf.Action(
        forwards={
            @Jpf.Forward(name="confirm", path="confirm.jsp"),
            @Jpf.Forward(name="nonefound", path="nonefound.jsp")
        },
        validationErrorForward=@Jpf.Forward(name="failure", navigateTo=Jpf.NavigateTo.currentPage)
   )
    protected Forward doSearch(SearchForm form)
    {
        // Of course, in real life we would be going through a Control to talk to some authoritative
        // source for airports/codes.

        String searchText = form.getSearchText().toLowerCase();

        for (Iterator i = AIRPORTS.iterator(); i.hasNext(); )
        {
            Results results = (Results) i.next();
            int pos = results.getAirport().toLowerCase().indexOf(searchText);

            if (pos == 0)
            {
                _currentResults = results;
                break;
            }
            else if (pos > 0 && _currentResults == null)
            {
                _currentResults = results;
            }
        }

        if (_currentResults == null)
        {
            return new Forward("nonefound");
        }

        return new Forward("confirm");
    }

    /**
     * This is the form bean that works with findairport.jsp.
     */
    @Jpf.FormBean()
    public static class SearchForm
        implements Serializable
    {
        private String _searchText;

        @Jpf.ValidatableProperty(
            displayNameKey="displayname.searchtext",
            validateRequired=@Jpf.ValidateRequired()
        )
        public String getSearchText()
        {
            return _searchText;
        }

        public void setSearchText(String st)
        {
            _searchText = st;
        }
    }

    /**
     * This is the bean we'll return to the original page flow.
     */
    public static class Results
        implements Serializable
    {
        private String _airport;
        private String _airportCode;

        public Results()
        {
        }

        public Results(String airportCode, String airport)
        {
            _airportCode = airportCode;
            _airport = airport;
        }

        public String getAirport()
        {
            return _airport;
        }

        public void setAirport(String airport)
        {
            _airport = airport;
        }

        public String getAirportCode()
        {
            return _airportCode;
        }

        public void setAirportCode(String code)
        {
            _airportCode = code;
        }
    }

    private static final ArrayList AIRPORTS = new ArrayList();

    static
    {
        AIRPORTS.add(new Results("AAE", "Annaba, Algeria - Les Salines"));
        AIRPORTS.add(new Results("AAL", "Aalborg, Denmark - Aalborg"));
        AIRPORTS.add(new Results("AAR", "Aarhus, Denmark - Tirstrup"));
        AIRPORTS.add(new Results("ABE", "Allentown, PA, USA - Allentown-Bethlehem-Easton Airport"));
        AIRPORTS.add(new Results("ABI", "Abilene, TX, USA - Municipal"));
        AIRPORTS.add(new Results("ABJ", "Abidjan, Cote D'ivoire - Port Bouet"));
        AIRPORTS.add(new Results("ABL", "Ambler, AK, USA"));
        AIRPORTS.add(new Results("ABM", "Bamaga, Queensland, Australia"));
        AIRPORTS.add(new Results("ABQ", "Albuquerque, NM, USA - Albuquerque International Airport"));
        AIRPORTS.add(new Results("ABR", "Aberdeen, SD, USA - Aberdeen Regional Airport"));
        AIRPORTS.add(new Results("ABS", "Abu Simbel, Egypt - Abu Simbel"));
        AIRPORTS.add(new Results("ABX", "Albury, New South Wales, Australia - Albury"));
        AIRPORTS.add(new Results("ABY", "Albany, GA, USA - Dougherty County"));
        AIRPORTS.add(new Results("ABZ", "Aberdeen, Scotland, United Kingdom - Dyce"));
        AIRPORTS.add(new Results("ACA", "Acapulco, Guerrero, Mexico - Alvarez International"));
        AIRPORTS.add(new Results("ACC", "Accra, Ghana - Kotoka"));
        AIRPORTS.add(new Results("ACE", "Lanzarote, Canary Islands, Spain - Lanzarote"));
        AIRPORTS.add(new Results("ACI", "Alderney, Channel Islands, United Kingdom - The Blaye"));
        AIRPORTS.add(new Results("ACK", "Nantucket, MA, USA"));
        AIRPORTS.add(new Results("ACT", "Waco, TX, USA - Madison Cooper"));
        AIRPORTS.add(new Results("ACV", "Arcata, CA, USA - Arcata/Eureka Airport"));
        AIRPORTS.add(new Results("ACY", "Atlantic City /Atlantic Cty, NJ, USA - Atlantic City International"));
        AIRPORTS.add(new Results("ADA", "Adana, Turkey - Adana"));
        AIRPORTS.add(new Results("ADB", "Izmir, Turkey - Adnam Menderes"));
        AIRPORTS.add(new Results("ADD", "Addis Ababa, Ethiopia - Bole"));
        AIRPORTS.add(new Results("ADJ", "Amman, Jordan - Civil"));
        AIRPORTS.add(new Results("ADL", "Adelaide, South Australia, Australia - Adelaide"));
        AIRPORTS.add(new Results("ADQ", "Kodiak, AK, USA"));
        AIRPORTS.add(new Results("ADZ", "San Andres Island, Colombia"));
        AIRPORTS.add(new Results("AEP", "Buenos Aires, Buenos Aires, Argentina - Jorge Newberry"));
        AIRPORTS.add(new Results("AES", "Aalesund, Norway - Vigra"));
        AIRPORTS.add(new Results("AET", "Allakaket, AK, USA"));
        AIRPORTS.add(new Results("AEX", "Alexandria, LA, USA - Alexandria Intl Airport"));
        AIRPORTS.add(new Results("AEY", "Akureyri, Iceland - Akureyri"));
        AIRPORTS.add(new Results("AGA", "Agadir, Morocco - Inezgane"));
        AIRPORTS.add(new Results("AGB", "Augsburg, Germany - Muehlhausen"));
        AIRPORTS.add(new Results("AGF", "Agen, France - La Garenne"));
        AIRPORTS.add(new Results("AGH", "Helsingborg, Sweden - Angelholm/Helsingborg"));
        AIRPORTS.add(new Results("AGP", "Malaga, Spain - Malaga"));
        AIRPORTS.add(new Results("AGR", "Agra, India - Kheria"));
        AIRPORTS.add(new Results("AGS", "Augusta, GA, USA - Bush Field"));
        AIRPORTS.add(new Results("AGU", "Aguascalientes, Aguascalientes, Mexico"));
        AIRPORTS.add(new Results("AHN", "Athens, GA, USA"));
        AIRPORTS.add(new Results("AHO", "Alghero, Sardinia, Italy - Fertilia"));
        AIRPORTS.add(new Results("AIA", "Alliance, NE, USA"));
        AIRPORTS.add(new Results("AIN", "Wainwright, AK, USA"));
        AIRPORTS.add(new Results("AJN", "Anjouan,Comoros"));
        AIRPORTS.add(new Results("AJA", "Ajaccio, Corsica, France - Campo Dell Oro"));
        AIRPORTS.add(new Results("AJU", "Aracaju, Sergipe, Brazil"));
        AIRPORTS.add(new Results("AKJ", "Asahikawa, Japan - Asahikawa"));
        AIRPORTS.add(new Results("AKL", "Auckland, New Zealand - Auckland International Airport"));
        AIRPORTS.add(new Results("ALA", "Almaty, Kazakhstan - Almaty"));
        AIRPORTS.add(new Results("ALB", "Albany, NY, USA - Albany County Airport"));
        AIRPORTS.add(new Results("ALC", "Alicante, Spain - Alicante"));
        AIRPORTS.add(new Results("ALE", "Alpine, TX, USA - Alpine Texas"));
        AIRPORTS.add(new Results("ALF", "Alta, Norway - Elvebakken"));
        AIRPORTS.add(new Results("ALG", "Algiers, Algeria - Houari Boumedienne"));
        AIRPORTS.add(new Results("ALM", "Alamogordo, NM, USA"));
        AIRPORTS.add(new Results("ALO", "Waterloo, IA, USA - Waterloo Municipal Airport"));
        AIRPORTS.add(new Results("ALP", "Aleppo, Syria - Nejrab"));
        AIRPORTS.add(new Results("ALS", "Alamosa, CO, USA - Bergman Field"));
        AIRPORTS.add(new Results("ALW", "Walla Walla, WA, USA"));
        AIRPORTS.add(new Results("ALY", "Alexandria, Egypt - Alexandria"));
        AIRPORTS.add(new Results("AMA", "Amarillo, TX, USA - Amarillo International Airport"));
        AIRPORTS.add(new Results("AMD", "Ahmedabad, India - Ahmedabad"));
        AIRPORTS.add(new Results("AMI", "Mataram, Indonesia - Selaparang"));
        AIRPORTS.add(new Results("AMM", "Amman, Jordan - Queen Alia International"));
        AIRPORTS.add(new Results("AMQ", "Ambon, Indonesia - Pattimura"));
        AIRPORTS.add(new Results("AMS", "Amsterdam, Netherlands - Schiphol"));
        AIRPORTS.add(new Results("ANB", "Anniston, AL, USA - Municipal"));
        AIRPORTS.add(new Results("ANC", "Anchorage, AK, USA - Anchorage International"));
        AIRPORTS.add(new Results("ANF", "Antofagasta, Chile - Cerro Moreno"));
        AIRPORTS.add(new Results("ANG", "Angouleme, France - Gel-Air"));
        AIRPORTS.add(new Results("ANI", "Aniak, AK, USA"));
        AIRPORTS.add(new Results("ANR", "Antwerp, Belgium - Deurne"));
        AIRPORTS.add(new Results("ANU", "Saint Johns / Antigua, Antigua And Barbuda - Vc Bird International"));
        AIRPORTS.add(new Results("ANV", "Anvik, AK, USA"));
        AIRPORTS.add(new Results("AOI", "Ancona, Italy - Falconara"));
        AIRPORTS.add(new Results("AOJ", "Aomori, Japan"));
        AIRPORTS.add(new Results("AOK", "Karpathos, Greece - Karpathos"));
        AIRPORTS.add(new Results("AOO", "Altoona / Martinsburg, PA, USA - Blair County"));
        AIRPORTS.add(new Results("AOR", "Alor Setar, Malaysia - Sultan Abdul Halim"));
        AIRPORTS.add(new Results("APF", "Naples, FL, USA"));
        AIRPORTS.add(new Results("APL", "NampulaMozambique"));
        AIRPORTS.add(new Results("APN", "Alpena, MI, USA - Alpena Regional Airport"));
        AIRPORTS.add(new Results("APW", "Apia, Samoa - Faleolo"));
        AIRPORTS.add(new Results("AQJ", "Aqaba, Jordan - Aqaba"));
        AIRPORTS.add(new Results("AQP", "Arequipa, Peru - Rodriguez Ballon"));
        AIRPORTS.add(new Results("ARH", "Arkhangelsk, Russia - Arkhangelsk"));
        AIRPORTS.add(new Results("ARI", "Arica, Chile - Chacalluta"));
        AIRPORTS.add(new Results("ARM", "Armidale, New South Wales, Australia - Armidale"));
        AIRPORTS.add(new Results("ARN", "Stockholm, Sweden - Arlanda International"));
        AIRPORTS.add(new Results("ART", "Watertown, NY, USA - Watertown"));
        AIRPORTS.add(new Results("ASD", "Andros Town, Bahamas"));
        AIRPORTS.add(new Results("ASE", "Aspen, CO, USA - Pitkin County Airport Sardy Field"));
        AIRPORTS.add(new Results("ASM", "Asmara, Eritrea - Asmara Intl/Yohannes Iv"));
        AIRPORTS.add(new Results("ASP", "Alice Springs, Northern Territory, Australia - Alice Springs"));
        AIRPORTS.add(new Results("ASU", "Asuncion, Paraguay - Silvio Pettirossi"));
        AIRPORTS.add(new Results("ASW", "Aswan, Egypt - Daraw"));
        AIRPORTS.add(new Results("ATC", "Arthurs Town, Bahamas"));
        AIRPORTS.add(new Results("ATH", "Athens, Greece - Hellinikon"));
        AIRPORTS.add(new Results("ATL", "Atlanta, GA, USA - Hartsfield International"));
        AIRPORTS.add(new Results("ATW", "Appleton, WI, USA - Outagamie County Airport"));
        AIRPORTS.add(new Results("ATY", "Watertown, SD, USA"));
        AIRPORTS.add(new Results("AUA", "Aruba, Aruba - Reina Beatrix"));
        AIRPORTS.add(new Results("AUC", "Arauca, Colombia"));
        AIRPORTS.add(new Results("AUG", "Augusta, ME, USA - Maine State"));
        AIRPORTS.add(new Results("AUH", "Abu Dhabi, United Arab Emirates - Abu Dhabi International"));
        AIRPORTS.add(new Results("AUS", "Austin, TX, USA - Robert Mueller Municipal Airport"));
        AIRPORTS.add(new Results("AVL", "Asheville / Hendersonville, NC, USA - Asheville Regional Airport"));
        AIRPORTS.add(new Results("AVN", "Avignon, France - Caumont"));
        AIRPORTS.add(new Results("AVP", "Wilkes Barre/Scranton, PA, USA - Wilkes-Barre/Scranton Intl"));
        AIRPORTS.add(new Results("AXA", "Anguilla, Anguilla"));
        AIRPORTS.add(new Results("AXD", "Alexandroupolis, Greece - Alexandroupolis"));
        AIRPORTS.add(new Results("AYQ", "Ayers Rock, Northern Territory, Australia - Connellan"));
        AIRPORTS.add(new Results("AYT", "Antalya, Turkey - Antalya"));
        AIRPORTS.add(new Results("AZO", "Kalamazoo, MI, USA - Kalamazoo/Battle Creek Intl"));
        AIRPORTS.add(new Results("BAH", "Bahrain, Bahrain - Bahrain International Bahrain"));
        AIRPORTS.add(new Results("BAK", "Baku, Azerbaijan - Baku"));
        AIRPORTS.add(new Results("BAL", "Batman, Turkey - Nearest Air Service Through Diyarbakir"));
        AIRPORTS.add(new Results("BAQ", "Barranquilla, Colombia - E Cortissoz"));
        AIRPORTS.add(new Results("BAX", "Barnaul, Russia - Barnaul Airport"));
        AIRPORTS.add(new Results("BBI", "Bhubaneswar, India - Bhubaneswar"));
        AIRPORTS.add(new Results("BBK", "Kasane, Botswana - Kasane"));
        AIRPORTS.add(new Results("BBU", "Bucharest, Romania - Baneasa"));
        AIRPORTS.add(new Results("BCD", "Bacolod, Philippines - Bacolod"));
        AIRPORTS.add(new Results("BCN", "Barcelona, Spain - Barcelona"));
        AIRPORTS.add(new Results("BDA", "Bermuda/Hamilton, Bermuda - Kindley Airfield/Civil Air Terminal"));
        AIRPORTS.add(new Results("BDJ", "Banjarmasin, Indonesia - Syamsudin Noor"));
        AIRPORTS.add(new Results("BDL", "Hartford, CT, USA - Bradley International Airport"));
        AIRPORTS.add(new Results("BDO", "Bandung, Indonesia - Husein Sastranegara"));
        AIRPORTS.add(new Results("BDQ", "Vadodara, India - Vadodara"));
        AIRPORTS.add(new Results("BDR", "Bridgeport, CT, USA - Sikorsky Memorial"));
        AIRPORTS.add(new Results("BED", "Bedford, MA, USA - Bedford"));
        AIRPORTS.add(new Results("BEG", "Belgrade, Yugoslavia - Belgrade-Beograd"));
        AIRPORTS.add(new Results("BEH", "Benton Harbor, MI, USA - Ross Field"));
        AIRPORTS.add(new Results("BEI", "Beica, Ethiopia - Beica"));
        AIRPORTS.add(new Results("BEL", "Belem, Para, Brazil - Val De Cans"));
        AIRPORTS.add(new Results("BEO", "Newcastle, New South Wales, Australia - Belmont"));
        AIRPORTS.add(new Results("BER", "Berlin, Germany - Schoenefeld"));
        AIRPORTS.add(new Results("BES", "Brest, France - Guipavas"));
        AIRPORTS.add(new Results("BET", "Bethel, AK, USA - Bethel"));
        AIRPORTS.add(new Results("BEW", "Beira, Mozambique - Beira"));
        AIRPORTS.add(new Results("BEY", "Beirut, Lebanon - International"));
        AIRPORTS.add(new Results("BFD", "Bradford, PA, USA - Bradford Regional"));
        AIRPORTS.add(new Results("BFF", "Scottsbluff, NE, USA - William B Heiling Field"));
        AIRPORTS.add(new Results("BFL", "Bakersfield, CA, USA - Meadows Field"));
        AIRPORTS.add(new Results("BFN", "Bloemfontein, South Africa - Jbm Hertzog"));
        AIRPORTS.add(new Results("BFS", "Belfast, Northern Ireland, United Kingdom - Belfast International"));
        AIRPORTS.add(new Results("BGA", "Bucaramanga, Colombia - Palo Negro"));
        AIRPORTS.add(new Results("BGF", "Bangui, Central African Republic - Bangui"));
        AIRPORTS.add(new Results("BGI", "Bridgetown, Barbados - Grantley Adams International"));
        AIRPORTS.add(new Results("BGK", "Big Creek, Belize - Big Creek"));
        AIRPORTS.add(new Results("BGM", "Binghamton/Endicott/Johnson City, NY, USA - Edwin Alink Field"));
        AIRPORTS.add(new Results("BGO", "Bergen, Norway - Flesland"));
        AIRPORTS.add(new Results("BGR", "Bangor, ME, USA - Bangor International Airport"));
        AIRPORTS.add(new Results("BGY", "Milan, Italy - Orio Al Serio"));
        AIRPORTS.add(new Results("BHB", "Bar Harbor, ME, USA"));
        AIRPORTS.add(new Results("BHD", "Belfast, Northern Ireland, United Kingdom - Belfast Harbor"));
        AIRPORTS.add(new Results("BHI", "Bahia Blanca, Buenos Aires, Argentina - Commandante"));
        AIRPORTS.add(new Results("BHK", "Bukhara, Uzbekistan"));
        AIRPORTS.add(new Results("BHM", "Birmingham, AL, USA - Seibels/Bryan Airport"));
        AIRPORTS.add(new Results("BHQ", "Broken Hill, New South Wales, Australia - Broken Hill"));
        AIRPORTS.add(new Results("BHS", "Bathurst, New South Wales, Australia - Raglan"));
        AIRPORTS.add(new Results("BHX", "Birmingham, England, United Kingdom - International"));
        AIRPORTS.add(new Results("BIA", "Bastia, Corsica, France - Poretta"));
        AIRPORTS.add(new Results("BIK", "Biak, Indonesia - Mokmer"));
        AIRPORTS.add(new Results("BIL", "Billings, MT, USA - Billings Logan Intnl Airport"));
        AIRPORTS.add(new Results("BIM", "Bimini, Bahamas - Bimini Island International"));
        AIRPORTS.add(new Results("BIO", "Bilbao, Spain - Sondica"));
        AIRPORTS.add(new Results("BIQ", "Biarritz, France - Parme"));
        AIRPORTS.add(new Results("BIS", "Bismarck, ND, USA - Bismarck Mannan Municipal"));
        AIRPORTS.add(new Results("BJI", "Bemidji, MN, USA - Bemidji Municipal Airport"));
        AIRPORTS.add(new Results("BJL", "Banjul, Gambia - Yundum International"));
        AIRPORTS.add(new Results("BJX", "Leon/Guanajuato, Guanajuato, Mexico - Del Bajio"));
        AIRPORTS.add(new Results("BKI", "Kota Kinabalu, Sabah, Malaysia - Kota Kinabalu"));
        AIRPORTS.add(new Results("BKK", "Bangkok, Thailand - Bangkok International Airport"));
        AIRPORTS.add(new Results("BKO", "Bamako, Mali - Senou"));
        AIRPORTS.add(new Results("BKW", "Beckley, WV, USA"));
        AIRPORTS.add(new Results("BKX", "Brookings, SD, USA - Brookings Municipal Airport"));
        AIRPORTS.add(new Results("BLA", "Barcelona, Venezuela - Gral Jose Antonio Anzoategui"));
        AIRPORTS.add(new Results("BLF", "Bluefield, WV, USA"));
        AIRPORTS.add(new Results("BLI", "Bellingham, WA, USA - Bellingham International"));
        AIRPORTS.add(new Results("BLK", "Blackpool, England, United Kingdom - Blackpool"));
        AIRPORTS.add(new Results("BLL", "Billund, Denmark - Billund"));
        AIRPORTS.add(new Results("BLQ", "Bologna, Italy - Guglielmo Marconi"));
        AIRPORTS.add(new Results("BLR", "Bangalore, India - Hindustan"));
        AIRPORTS.add(new Results("BLZ", "Blantyre, Malawi - Chileka"));
        AIRPORTS.add(new Results("BMA", "Stockholm, Sweden - Bromma Arpt"));
        AIRPORTS.add(new Results("BMG", "Bloomington, IN, USA - Monroe County Airport"));
        AIRPORTS.add(new Results("BMI", "Bloomington, IL, USA - Normal"));
        AIRPORTS.add(new Results("BNA", "Nashville, TN, USA - Nashville Metropolitan Airport"));
        AIRPORTS.add(new Results("BNE", "Brisbane, Queensland, Australia - Brisbane International Airport"));
        AIRPORTS.add(new Results("BNJ", "Bonn, Germany - Train Main Railroad Station"));
        AIRPORTS.add(new Results("BNN", "Bronnoysund, Norway - Bronnoy"));
        AIRPORTS.add(new Results("BNS", "Barinas, Venezuela - Barinas"));
        AIRPORTS.add(new Results("BOD", "Bordeaux, France - Merignac"));
        AIRPORTS.add(new Results("BOG", "Bogota, Colombia - Eldorado"));
        AIRPORTS.add(new Results("BOI", "Boise, ID, USA - Boise Municipal Arpt (Gowen Field)"));
        AIRPORTS.add(new Results("BOM", "Bombay, India - Bombay"));
        AIRPORTS.add(new Results("BON", "Bonaire, Netherlands Antilles - Flamingo Field"));
        AIRPORTS.add(new Results("BOO", "Bodo, Norway - Bodo"));
        AIRPORTS.add(new Results("BOS", "Boston, MA, USA - Logan International Airport"));
        AIRPORTS.add(new Results("BPS", "Porto Seguro, Bahia, Brazil - Porto Seguro"));
        AIRPORTS.add(new Results("BPT", "Beaumont, TX, USA - Jefferson County"));
        AIRPORTS.add(new Results("BQK", "Brunswick, GA, USA - Glynco Jetport"));
        AIRPORTS.add(new Results("BQN", "Aguadilla, PR, USA"));
        AIRPORTS.add(new Results("BRC", "San Carlos De Bariloche, Rio Negro, Argentina - International"));
        AIRPORTS.add(new Results("BRD", "Brainerd, MN, USA"));
        AIRPORTS.add(new Results("BRE", "Bremen, Germany - Bremen"));
        AIRPORTS.add(new Results("BRI", "Bari, Italy"));
        AIRPORTS.add(new Results("BRL", "Burlington, IA, USA - Burlington Municipal Airport"));
        AIRPORTS.add(new Results("BRM", "Barquisimeto, Venezuela - Barquisimeto"));
        AIRPORTS.add(new Results("BRN", "Berne, Switzerland - Belp"));
        AIRPORTS.add(new Results("BRO", "Brownsville, TX, USA - South Padre Island Intl"));
        AIRPORTS.add(new Results("BRQ", "Brno, Czech Republic - Turany"));
        AIRPORTS.add(new Results("BRR", "Barra / Hebrides Islands, Scotland, United Kingdom - North Bay"));
        AIRPORTS.add(new Results("BRS", "Bristol, England, United Kingdom - Bristol"));
        AIRPORTS.add(new Results("BRT", "Bathurst Island, Northern Territory, Australia"));
        AIRPORTS.add(new Results("BRU", "Brussels, Belgium - National"));
        AIRPORTS.add(new Results("BRW", "Barrow, AK, USA - Barrow"));
        AIRPORTS.add(new Results("BSB", "Brasilia, Distrito Federal, Brazil - International"));
        AIRPORTS.add(new Results("BSK", "Biskra, Algeria - Biskra"));
        AIRPORTS.add(new Results("BSL", "Basel, Switzerland - Basel"));
        AIRPORTS.add(new Results("BTM", "Butte, MT, USA"));
        AIRPORTS.add(new Results("BTS", "Bratislava, Slovakia - Ivanka"));
        AIRPORTS.add(new Results("BTU", "Bintulu, Sarawak, Malaysia - Bintulu"));
        AIRPORTS.add(new Results("BTV", "Burlington, VT, USA - Burlington International Airport"));
        AIRPORTS.add(new Results("BUD", "Budapest, Hungary - Ferihegy"));
        AIRPORTS.add(new Results("BUF", "Buffalo, NY, USA - Greater Buffalo Intl Airport"));
        AIRPORTS.add(new Results("BUQ", "Bulawayo, Zimbabwe - Bulawayo"));
        AIRPORTS.add(new Results("BUR", "Burbank, CA, USA - Burbank Glendale Pasadena Airport"));
        AIRPORTS.add(new Results("BUZ", "Bushehr, Iran - Bushehr"));
        AIRPORTS.add(new Results("BVB", "Boa Vista, Roraima, Brazil"));
        AIRPORTS.add(new Results("BVE", "Brive-La-Gaillarde, France - Laroche"));
        AIRPORTS.add(new Results("BVI", "Birdsville, Queensland, Australia - Birdsville"));
        AIRPORTS.add(new Results("BWA", "Bhairawa, Nepal - Bhairawa"));
        AIRPORTS.add(new Results("BWI", "Baltimore, MD, USA - Baltimore-Washington International"));
        AIRPORTS.add(new Results("BWN", "Bandar Seri Begawan, Brunei Darussalam - Brunei International"));
        AIRPORTS.add(new Results("BXN", "Bodrum, Turkey - Imsik Airport"));
        AIRPORTS.add(new Results("BXU", "Butuan, Philippines - Butuan"));
        AIRPORTS.add(new Results("BYU", "Bayreuth, Germany - Bindlacher Berg"));
        AIRPORTS.add(new Results("BZE", "Belize City, Belize - Belize International"));
        AIRPORTS.add(new Results("BZN", "Bozeman, MT, USA - Gallatin Field"));
        AIRPORTS.add(new Results("BZR", "Beziers, France - Beziers-Vias"));
        AIRPORTS.add(new Results("CAE", "Columbia, SC, USA - Columbia Sc Airport Metropolitan"));
        AIRPORTS.add(new Results("CAG", "Cagliari, Sardinia, Italy - Elmas"));
        AIRPORTS.add(new Results("CAI", "Cairo, Egypt - International"));
        AIRPORTS.add(new Results("CAJ", "Canaima, Venezuela"));
        AIRPORTS.add(new Results("CAK", "Akron/Canton, OH, USA - Akron-Canton Regional Airport"));
        AIRPORTS.add(new Results("CAN", "Guangzhou, China - Baiyun"));
        AIRPORTS.add(new Results("CAS", "Casablanca, Morocco - Anfa"));
        AIRPORTS.add(new Results("CAY", "Cayenne, French Guiana - Rochambeau"));
        AIRPORTS.add(new Results("CBB", "Cochabamba, Bolivia - San Jose De La Banda"));
        AIRPORTS.add(new Results("CBE", "Cumberland, MD, USA - Municipal"));
        AIRPORTS.add(new Results("CBG", "Cambridge, England, United Kingdom - Cambridge"));
        AIRPORTS.add(new Results("CBL", "Ciudad Bolivar, Venezuela"));
        AIRPORTS.add(new Results("CBR", "Canberra, Australian Capital Territory, Australia - Canberra"));
        AIRPORTS.add(new Results("CCF", "Carcassonne, France - Salvaza Airport"));
        AIRPORTS.add(new Results("CCJ", "Calicut, India"));
        AIRPORTS.add(new Results("CCP", "Concepcion, Chile - Carriel Sur"));
        AIRPORTS.add(new Results("CCS", "Caracas, Venezuela - Simon Bolivar International"));
        AIRPORTS.add(new Results("CCU", "Calcutta, India - Calcutta"));
        AIRPORTS.add(new Results("CDC", "Cedar City, UT, USA"));
        AIRPORTS.add(new Results("CDG", "Paris, France - Charles De Gaulle"));
        AIRPORTS.add(new Results("CDH", "Camden, AR, USA"));
        AIRPORTS.add(new Results("CDR", "Chadron, NE, USA"));
        AIRPORTS.add(new Results("CDV", "Cordova, AK, USA"));
        AIRPORTS.add(new Results("CEB", "Cebu, Philippines - International"));
        AIRPORTS.add(new Results("CEC", "Crescent City, CA, USA - Crescent City Municipal Airport"));
        AIRPORTS.add(new Results("CEI", "Chiang Rai, Thailand - Chiang Rai"));
        AIRPORTS.add(new Results("CEN", "Ciudad Obregon, Sonora, Mexico"));
        AIRPORTS.add(new Results("CER", "Cherbourg, France - Maupertus"));
        AIRPORTS.add(new Results("CEZ", "Cortez, CO, USA - Montezuma County"));
        AIRPORTS.add(new Results("CFR", "Caen, France - Carpiquet"));
        AIRPORTS.add(new Results("CFU", "Kerkyra, Greece - Kerkyra"));
        AIRPORTS.add(new Results("CGA", "Craig, AK, USA"));
        AIRPORTS.add(new Results("CGB", "Cuiaba, Mato Grosso, Brazil"));
        AIRPORTS.add(new Results("CGH", "Sao Paulo, Sao Paulo, Brazil - Congonhas"));
        AIRPORTS.add(new Results("CGI", "Cape Girardeau, MO, USA - Municipal Airport"));
        AIRPORTS.add(new Results("CGK", "Jakarta, Indonesia - Soekarno Hatta International"));
        AIRPORTS.add(new Results("CGN", "Cologne/Bonn, Germany - Koeln/Bonn"));
        AIRPORTS.add(new Results("CGO", "Zhengzhou, China"));
        AIRPORTS.add(new Results("CGP", "Chittagong, Bangladesh - Patenga"));
        AIRPORTS.add(new Results("CGQ", "Changchun, China"));
        AIRPORTS.add(new Results("CGR", "Campo Grande, Mato Grosso Do Sul, Brazil"));
        AIRPORTS.add(new Results("CGX", "Chicago, IL, USA - Meigs Field"));
        AIRPORTS.add(new Results("CGX", "Chicago, IL, USA - Midway / Ohare / Meigs"));
        AIRPORTS.add(new Results("CHA", "Chattanooga, TN, USA - Cha Lovell Field"));
        AIRPORTS.add(new Results("CHC", "Christchurch, New Zealand - International"));
        AIRPORTS.add(new Results("CHO", "Charlottesville, VA, USA - Charlottesville/Albemarle"));
        AIRPORTS.add(new Results("CHQ", "Chania, Crete Island, Greece - Souda"));
        AIRPORTS.add(new Results("CHS", "Charleston, SC, USA - Charleston International Airport"));
        AIRPORTS.add(new Results("CIA", "Rome, Italy - Ciampino"));
        AIRPORTS.add(new Results("CIC", "Chico, CA, USA - Chico Municipal Air Terminal"));
        AIRPORTS.add(new Results("CID", "Cedar Rapids, IA, USA - Municipal"));
        AIRPORTS.add(new Results("CIU", "Sault Ste Marie, MI, USA - Chippewa County Intl Airport"));
        AIRPORTS.add(new Results("CIX", "Chiclayo, Peru - Cornel Ruiz"));
        AIRPORTS.add(new Results("CJB", "Coimbatore, India - Peelamedu"));
        AIRPORTS.add(new Results("CJS", "Ciudad Juarez, Chihuahua, Mexico - International Abraham Gonzalez"));
        AIRPORTS.add(new Results("CJU", "Cheju, South Korea - Cheju"));
        AIRPORTS.add(new Results("CKB", "Clarksburg, WV, USA - Clarksburg-Benedum Airport"));
        AIRPORTS.add(new Results("CKS", "Carajas, Para, Brazil - International / Brasilia Brazil"));
        AIRPORTS.add(new Results("CKY", "Conakry, Guinea - Conakry"));
        AIRPORTS.add(new Results("CLD", "Carlsbad, CA, USA - Carlsbad/Palomar Airport"));
        AIRPORTS.add(new Results("CLE", "Cleveland, OH, USA - Hopkins International Airport"));
        AIRPORTS.add(new Results("CLJ", "Cluj, Romania - Cluj"));
        AIRPORTS.add(new Results("CLL", "College Station, TX, USA"));
        AIRPORTS.add(new Results("CLM", "Port Angeles, WA, USA - Wm Fairchild Intl Airport"));
        AIRPORTS.add(new Results("CLO", "Cali, Colombia - Alfonso Bonilla Aragon"));
        AIRPORTS.add(new Results("CLQ", "Colima, Colima, Mexico"));
        AIRPORTS.add(new Results("CLT", "Charlotte, NC, USA - Charlotte/Douglas Intl Airport"));
        AIRPORTS.add(new Results("CLY", "Calvi, Corsica, France - Ste Catherine"));
        AIRPORTS.add(new Results("CMB", "Colombo, Sri Lanka - Katunayake International"));
        AIRPORTS.add(new Results("CME", "Ciudad Del Carmen, Campeche, Mexico"));
        AIRPORTS.add(new Results("CMF", "Chambery, France - Chambery Aix-Les-Bains"));
        AIRPORTS.add(new Results("CMG", "Corumba, Mato Grosso Do Sul, Brazil - Corumba"));
        AIRPORTS.add(new Results("CMH", "Columbus, OH, USA - Port Columbus Intl Airport"));
        AIRPORTS.add(new Results("CMI", "Champaign, IL, USA - Univ Of Illinois-Willard Airport"));
        AIRPORTS.add(new Results("CMN", "Casablanca, Morocco - Mohamed V"));
        AIRPORTS.add(new Results("CMX", "Hancock, MI, USA - Houghton County / Memorial"));
        AIRPORTS.add(new Results("CND", "Constanta, Romania - Kogalniceanu"));
        AIRPORTS.add(new Results("CNF", "Belo Horizonte /Belo Horizon, Minas Gerais, Brazil - Aeropuerto Internacional Tancredo Neves"));
        AIRPORTS.add(new Results("CNM", "Carlsbad, NM, USA"));
        AIRPORTS.add(new Results("CNS", "Cairns, Queensland, Australia - Cairns"));
        AIRPORTS.add(new Results("CNX", "Chiang Mai, Thailand - International"));
        AIRPORTS.add(new Results("CNY", "Moab, UT, USA"));
        AIRPORTS.add(new Results("COK", "Cochin, India - Naval Air Station"));
        AIRPORTS.add(new Results("COO", "Cotonou, Benin - Cotonou"));
        AIRPORTS.add(new Results("COR", "Cordoba, Cordoba, Argentina - Pajas Blancas"));
        AIRPORTS.add(new Results("COS", "Colorado Springs, CO, USA - Colorado Springs Municipal"));
        AIRPORTS.add(new Results("COU", "Columbia, MO, USA - Columbia Regional"));
        AIRPORTS.add(new Results("CPC", "San Martin De Los Andes, Neuquen, Argentina"));
        AIRPORTS.add(new Results("CPH", "Copenhagen, Denmark - Copenhagen"));
        AIRPORTS.add(new Results("CPQ", "Campinas, Sao Paulo, Brazil - Campinas International"));
        AIRPORTS.add(new Results("CPR", "Casper, WY, USA - Natrona County Intl Airport"));
        AIRPORTS.add(new Results("CPT", "Cape Town, South Africa - D F Malan"));
        AIRPORTS.add(new Results("CRD", "Comodoro Rivadavia, Chubut, Argentina - Comodora Rivadavia"));
        AIRPORTS.add(new Results("CRI", "Crooked Island, Bahamas"));
        AIRPORTS.add(new Results("CRP", "Corpus Christi, TX, USA - Corpus Christi International Airport"));
        AIRPORTS.add(new Results("CRU", "Carriacou Island, Grenada"));
        AIRPORTS.add(new Results("CRW", "Charleston, WV, USA - Yeager Airport"));
        AIRPORTS.add(new Results("CSG", "Columbus, GA, USA - Columbus Metropolitan / Fort Benning"));
        AIRPORTS.add(new Results("CSX", "Changsha, China"));
        AIRPORTS.add(new Results("CTA", "Catania, Sicily, Italy - Fontanarossa"));
        AIRPORTS.add(new Results("CTG", "Cartagena, Colombia - Rafael Nunez"));
        AIRPORTS.add(new Results("CTL", "Charleville, Queensland, Australia - Charleville"));
        AIRPORTS.add(new Results("CTS", "Sapporo, Japan - Chitose"));
        AIRPORTS.add(new Results("CTU", "Chengdu, China"));
        AIRPORTS.add(new Results("CUC", "Cucuta, Colombia - Camilo Daza"));
        AIRPORTS.add(new Results("CUE", "Cuenca, Ecuador - Mariscal La Mar"));
        AIRPORTS.add(new Results("CUL", "Culiacan, Sinaloa, Mexico"));
        AIRPORTS.add(new Results("CUM", "Cumana, Venezuela"));
        AIRPORTS.add(new Results("CUN", "Cancun, Mexico"));
        AIRPORTS.add(new Results("CUP", "Carupano, Venezuela - Carupano"));
        AIRPORTS.add(new Results("CUR", "Willemstad / Curacao Island, Netherlands Antilles - Areopuerto Hato"));
        AIRPORTS.add(new Results("CUU", "Chihuahua, Chihuahua, Mexico - Genvillalobos"));
        AIRPORTS.add(new Results("CUZ", "Cuzco, Peru - Tte Velazco Astete"));
        AIRPORTS.add(new Results("CVG", "Cincinnati, OH, USA - Greater Cincinnati Intl Airport"));
        AIRPORTS.add(new Results("CVN", "Clovis, NM, USA"));
        AIRPORTS.add(new Results("CWA", "Wausau, WI, USA - Central Wisconsin Airport"));
        AIRPORTS.add(new Results("CWB", "Curitiba, Parana, Brazil - Afonso Pena"));
        AIRPORTS.add(new Results("CWL", "Cardiff, Wales, United Kingdom - Cardiff-Wales"));
        AIRPORTS.add(new Results("CWT", "Cowra, New South Wales, Australia - Cowra"));
        AIRPORTS.add(new Results("CXH", "Vancouver, British Columbia, Canada - Vancouver Harbour Airport"));
        AIRPORTS.add(new Results("CYB", "Cayman Brac Island, Cayman Islands"));
        AIRPORTS.add(new Results("CYR", "Colonia, Uruguay"));
        AIRPORTS.add(new Results("CYS", "Cheyenne, WY, USA - Cheyenne Municipal Airport"));
        AIRPORTS.add(new Results("CZM", "Cozumel, Quintana Roo, Mexico - Aeropuerto Intl De Cozumel"));
        AIRPORTS.add(new Results("DAB", "Daytona Beach, FL, USA - Daytona Beach International Airport"));
        AIRPORTS.add(new Results("DAC", "Dhaka, Bangladesh - Zia International Airport"));
        AIRPORTS.add(new Results("DAD", "Da Nang, Vietnam - Da Nang"));
        AIRPORTS.add(new Results("DAL", "Dallas, TX, USA - Love Field"));
        AIRPORTS.add(new Results("DAM", "Damascus, Syria - Damascus Intl"));
        AIRPORTS.add(new Results("DAN", "Danville, VA, USA"));
        AIRPORTS.add(new Results("DAR", "Dar Es Salaam, Tanzania - International"));
        AIRPORTS.add(new Results("DAY", "Dayton, OH, USA - James M Cox Dayton International"));
        AIRPORTS.add(new Results("DBO", "Dubbo, New South Wales, Australia - Dubbo"));
        AIRPORTS.add(new Results("DBQ", "Dubuque, IA, USA - Dubuque Municipal Airport"));
        AIRPORTS.add(new Results("DBV", "Dubrovnik, Croatia - Hrvatska"));
        AIRPORTS.add(new Results("DCA", "Washington, DC, USA - Washington National Airport"));
        AIRPORTS.add(new Results("DCF", "Dominica, Dominica - Cane Field"));
        AIRPORTS.add(new Results("DDC", "Dodge City, KS, USA - Dodge City Municipal"));
        AIRPORTS.add(new Results("DEC", "Decatur, IL, USA - Decatur Municiple Airport"));
        AIRPORTS.add(new Results("DEL", "Delhi, India - Delhi International Airport"));
        AIRPORTS.add(new Results("DEM", "Dembidollo, Ethiopia - Dembidollo"));
        AIRPORTS.add(new Results("DEN", "Denver, CO, USA - Denver International"));
        AIRPORTS.add(new Results("DFW", "Dallas/Ft Worth, TX, USA - Dallas Ft Worth International"));
        AIRPORTS.add(new Results("DGA", "Dangriga, Belize - Dangriga"));
        AIRPORTS.add(new Results("DGO", "Durango, Durango, Mexico - Gen Guadalupe Victoria"));
        AIRPORTS.add(new Results("DHA", "Dhahran, Saudi Arabia - Dhahran Intl"));
        AIRPORTS.add(new Results("DHN", "Dothan, AL, USA - Municipal"));
        AIRPORTS.add(new Results("DIB", "Dibrugarh, India - Chabua"));
        AIRPORTS.add(new Results("DIJ", "Dijon, France - Longvic"));
        AIRPORTS.add(new Results("DIL", "Dili, Indonesia - Comoro"));
        AIRPORTS.add(new Results("DIY", "Diyarbakir, Turkey - Diyarbakia"));
        AIRPORTS.add(new Results("DKR", "Dakar, Senegal - Yoff"));
        AIRPORTS.add(new Results("DLA", "Douala, Cameroon - Douala"));
        AIRPORTS.add(new Results("DLC", "Dalian, China"));
        AIRPORTS.add(new Results("DLH", "Duluth, MN, USA - Duluth International Airport"));
        AIRPORTS.add(new Results("DLM", "Dalaman, Turkey - Dalaman"));
        AIRPORTS.add(new Results("DME", "Moscow, Russia - Domodedovo"));
        AIRPORTS.add(new Results("DND", "Dundee, Scotland, United Kingdom - Dundee"));
        AIRPORTS.add(new Results("DNM", "Denham, Western Australia, Australia"));
        AIRPORTS.add(new Results("DNV", "Danville, IL, USA - Vermilion County Airport"));
        AIRPORTS.add(new Results("DOH", "Doha, Qatar - Doha"));
        AIRPORTS.add(new Results("DOK", "Donetsk, Ukraine - Donetsk"));
        AIRPORTS.add(new Results("DOL", "Deauville, France - Saint Gatien"));
        AIRPORTS.add(new Results("DOM", "Dominica, Dominica - Melville Hal-Dom"));
        AIRPORTS.add(new Results("DPL", "Dipolog, Philippines - Dipolog"));
        AIRPORTS.add(new Results("DPO", "Devonport, Tasmania, Australia - Devonport"));
        AIRPORTS.add(new Results("DPS", "Denpasar Bali, Indonesia - Ngurah Rai"));
        AIRPORTS.add(new Results("DRO", "Durango, CO, USA - Durango La Plata County Airport"));
        AIRPORTS.add(new Results("DRS", "Dresden, Germany - Dresden"));
        AIRPORTS.add(new Results("DRT", "Del Rio, TX, USA"));
        AIRPORTS.add(new Results("DRW", "Darwin, Northern Territory, Australia"));
        AIRPORTS.add(new Results("DSI", "Destin, FL, USA"));
        AIRPORTS.add(new Results("DSM", "Des Moines, IA, USA"));
        AIRPORTS.add(new Results("DTM", "Dortmund, Germany - Wickede"));
        AIRPORTS.add(new Results("DTW", "Detroit, MI, USA - Detroit Metropolitan Airport"));
        AIRPORTS.add(new Results("DUB", "Dublin, Ireland - Dublin"));
        AIRPORTS.add(new Results("DUD", "Dunedin, New Zealand - Momona"));
        AIRPORTS.add(new Results("DUJ", "Du Bois, PA, USA - Jefferson County"));
        AIRPORTS.add(new Results("DUQ", "Duncan / Quam, British Columbia, Canada - Quamichan Lake"));
        AIRPORTS.add(new Results("DUR", "Durban, South Africa - Louis Botha"));
        AIRPORTS.add(new Results("DUS", "Dusseldorf, Germany - Dusseldorf"));
        AIRPORTS.add(new Results("DUT", "Dutch Harbor, AK, USA - Dutch Harbor"));
        AIRPORTS.add(new Results("DVO", "Davao, Philippines - Mati"));
        AIRPORTS.add(new Results("DXB", "Dubai, United Arab Emirates - Dubai International Airport"));
        AIRPORTS.add(new Results("EAR", "Kearney, NE, USA - Kearney Municipal Airport"));
        AIRPORTS.add(new Results("EAS", "San Sebastian, Spain - Fuenterrabia"));
        AIRPORTS.add(new Results("EAT", "Wenatchee, WA, USA - Pangborn Memorial Field"));
        AIRPORTS.add(new Results("EAU", "Eau Claire, WI, USA - Eau Claire Municipal"));
        AIRPORTS.add(new Results("EBA", "Elba Island, Italy - Marina Di Campo"));
        AIRPORTS.add(new Results("EBB", "Entebbe/Kampala, Uganda - Entebbe"));
        AIRPORTS.add(new Results("EBJ", "Esbjerg, Denmark - Esbjerg"));
        AIRPORTS.add(new Results("EDI", "Edinburgh, Scotland, United Kingdom - Turnhouse"));
        AIRPORTS.add(new Results("EDR", "Edward River, Queensland, Australia - Edward River"));
        AIRPORTS.add(new Results("EEN", "Keene / Brattleboro, NH, USA - Dillant Hopkins"));
        AIRPORTS.add(new Results("EFD", "Houston, TX, USA - Ellington Field"));
        AIRPORTS.add(new Results("EGE", "Vail/Eagle, CO, USA - Eagle County Regional"));
        AIRPORTS.add(new Results("EIN", "Eindhoven, Netherlands - Welschap"));
        AIRPORTS.add(new Results("EIS", "Tortola/Beef Island, Virgin Islands (British) - Beef Island"));
        AIRPORTS.add(new Results("EJA", "Barrancabermeja, Colombia - Variguies"));
        AIRPORTS.add(new Results("EKO", "Elko, NV, USA - J C Harris Field"));
        AIRPORTS.add(new Results("ELD", "El Dorado, AR, USA"));
        AIRPORTS.add(new Results("ELH", "North Eleuthera, Bahamas"));
        AIRPORTS.add(new Results("ELM", "Elmira / Corning, NY, USA - Elmira Corning Regional Arpt"));
        AIRPORTS.add(new Results("ELP", "El Paso, TX, USA - El Paso International Airport"));
        AIRPORTS.add(new Results("ELS", "East London, South Africa - Ben Shoeman"));
        AIRPORTS.add(new Results("ELY", "Ely, NV, USA - Yelland Field"));
        AIRPORTS.add(new Results("EMA", "East Midlands, England, United Kingdom - East Midlands"));
        AIRPORTS.add(new Results("EMD", "Emerald, Queensland, Australia - Emerald"));
        AIRPORTS.add(new Results("ENA", "Kenai, AK, USA - Kenai Municipal Airport"));
        AIRPORTS.add(new Results("ENS", "Enschede, Netherlands - Twente"));
        AIRPORTS.add(new Results("EOH", "Medellin, Colombia - Enrique Olaya Herrara"));
        AIRPORTS.add(new Results("EPR", "Esperance, Western Australia, Australia - Esperance"));
        AIRPORTS.add(new Results("ERF", "Erfurt, Germany - Erfurt"));
        AIRPORTS.add(new Results("ERI", "Erie, PA, USA - Erie International"));
        AIRPORTS.add(new Results("ERS", "Windhoek, Namibia - Eros"));
        AIRPORTS.add(new Results("ERZ", "Erzurum, Turkey - Erzurum"));
        AIRPORTS.add(new Results("ESB", "Ankara, Turkey - Esenboga"));
        AIRPORTS.add(new Results("ESC", "Escanaba, MI, USA - Delta County Airport"));
        AIRPORTS.add(new Results("ESD", "Eastsound, WA, USA - Eastsound/Orcas Island Airport"));
        AIRPORTS.add(new Results("ESR", "El Salvador, Chile"));
        AIRPORTS.add(new Results("ETH", "Elat, Israel - Elat"));
        AIRPORTS.add(new Results("ETZ", "Metz/Nancy, France - Frescaty"));
        AIRPORTS.add(new Results("EUG", "Eugene, OR, USA - Eugene Airport"));
        AIRPORTS.add(new Results("EUN", "Laayoune, Morocco - Laayoune-Hassan I Morocco"));
        AIRPORTS.add(new Results("EVE", "Evenes, Norway - Evenes"));
        AIRPORTS.add(new Results("EVN", "Yerevan, Armenia"));
        AIRPORTS.add(new Results("EVV", "Evansville, IN, USA - Evansville Regional Airport"));
        AIRPORTS.add(new Results("EWB", "New Bedford/Fall River, MA, USA - New Bedford Municipal"));
        AIRPORTS.add(new Results("EWN", "New Bern, NC, USA - Simmons-Nott Airport"));
        AIRPORTS.add(new Results("EWR", "Newark, NJ, USA - Newark International Airport"));
        AIRPORTS.add(new Results("EXT", "Exeter, England, United Kingdom - Exeter"));
        AIRPORTS.add(new Results("EYW", "Key West, FL, USA"));
        AIRPORTS.add(new Results("EZE", "Buenos Aires, Buenos Aires, Argentina - Eze - Ezeiza International Airport"));
        AIRPORTS.add(new Results("FAE", "Faroe Islands, Faroe Islands - Faeroe Islands"));
        AIRPORTS.add(new Results("FAI", "Fairbanks, AK, USA - Fairbanks International Airport"));
        AIRPORTS.add(new Results("FAO", "Faro, Portugal - Faro"));
        AIRPORTS.add(new Results("FAR", "Fargo, ND, USA - Hector Airport"));
        AIRPORTS.add(new Results("FAT", "Fresno, CA, USA - Fresno Air Terminal"));
        AIRPORTS.add(new Results("FAY", "Fayetteville, NC, USA - Fayetteville Municipal"));
        AIRPORTS.add(new Results("FBU", "Oslo, Norway - Fornebu"));
        AIRPORTS.add(new Results("FCA", "Kalispell, MT, USA - Glacier Park International"));
        AIRPORTS.add(new Results("FCO", "Rome, Italy - Leonardo Da Vinci/Fiumicino"));
        AIRPORTS.add(new Results("FDE", "Forde, Norway - Forde"));
        AIRPORTS.add(new Results("FDF", "Fort De France, Martinique - Fort De France"));
        AIRPORTS.add(new Results("FDH", "Friedrichshafen, Germany - Friedrichshafen - Lowenthal"));
        AIRPORTS.add(new Results("FEZ", "Fez, Morocco - Fez"));
        AIRPORTS.add(new Results("FFM", "Fergus Falls, MN, USA - Fergus Falls Municipal Airport"));
        AIRPORTS.add(new Results("FHU", "Fort Huachuca/Sierra Vista, AZ, USA"));
        AIRPORTS.add(new Results("FIH", "Kinshasa, Zaire - Kinshasa"));
        AIRPORTS.add(new Results("FKL", "Franklin, PA, USA - Chess Lamberton"));
        AIRPORTS.add(new Results("FLG", "Flagstaff, AZ, USA - Flagstaff"));
        AIRPORTS.add(new Results("FLL", "Ft Lauderdale, FL, USA - Ft Lauderdale/Hollywood Intl Apt"));
        AIRPORTS.add(new Results("FLN", "Florianopolis, Santa Catarina, Brazil - Florianopolis"));
        AIRPORTS.add(new Results("FLO", "Florence, SC, USA - Gilbert Field"));
        AIRPORTS.add(new Results("FLR", "Florence, Italy"));
        AIRPORTS.add(new Results("FMA", "Formosa, Formosa, Argentina - Formosa"));
        AIRPORTS.add(new Results("FMN", "Farmington, NM, USA - Four Corners Regional Airport"));
        AIRPORTS.add(new Results("FMO", "Muenster, Germany - Muenster"));
        AIRPORTS.add(new Results("FNC", "Funchal, Madeira Islands, Portugal - Funchal"));
        AIRPORTS.add(new Results("FNL", "Fort Collins/Loveland, CO, USA - Fort Collins / Loveland Airport"));
        AIRPORTS.add(new Results("FNT", "Flint, MI, USA - Bishop Int'l Airport"));
        AIRPORTS.add(new Results("FOD", "Fort Dodge, IA, USA - Fort Dodge Regional Airport"));
        AIRPORTS.add(new Results("FOE", "Topeka, KS, USA - Forbes Field"));
        AIRPORTS.add(new Results("FOR", "Fortaleza, Ceara, Brazil - Fortaleza"));
        AIRPORTS.add(new Results("FPO", "Freeport, Bahamas - Freeport Intl Airport"));
        AIRPORTS.add(new Results("FRA", "Frankfurt, Germany - Frankfurt International"));
        AIRPORTS.add(new Results("FRD", "Friday Harbor, WA, USA - Friday Harbor Airport"));
        AIRPORTS.add(new Results("FRM", "Fairmont, MN, USA - Fairmont Municipal"));
        AIRPORTS.add(new Results("FRO", "Floro, Norway - Floro"));
        AIRPORTS.add(new Results("FRS", "Flores, Guatemala - Flores"));
        AIRPORTS.add(new Results("FRU", "Bishkek, Kyrgyzstan - Bishkek Airport"));
        AIRPORTS.add(new Results("FSD", "Sioux Falls, SD, USA - Joe Foss Field"));
        AIRPORTS.add(new Results("FSM", "Fort Smith, AR, USA - Fort Smith Municipal"));
        AIRPORTS.add(new Results("FSP", "St Pierre, St. Pierre And Miquelon"));
        AIRPORTS.add(new Results("FUE", "Fuerteventura / Puerto Del Rosario, Canary Islands/Fuerteventura Island, Spain - Fuerteventura"));
        AIRPORTS.add(new Results("FUK", "Fukuoka, Japan - Itazuke"));
        AIRPORTS.add(new Results("FWA", "Fort Wayne, IN, USA - Baer Field"));
        AIRPORTS.add(new Results("FYV", "Fayetteville, AR, USA - Municipal"));
        AIRPORTS.add(new Results("GAJ", "Yamagata, Japan - Junmachi"));
        AIRPORTS.add(new Results("GAL", "Galena, AK, USA"));
        AIRPORTS.add(new Results("GAU", "Gauhati, India - Borjhar"));
        AIRPORTS.add(new Results("GBE", "Gaborone, Botswana - Gaborone"));
        AIRPORTS.add(new Results("GBG", "Galesburg, IL, USA - Galesburg Municiple Airport"));
        AIRPORTS.add(new Results("GCC", "Gillette, WY, USA - Campbell County Airport"));
        AIRPORTS.add(new Results("GCI", "Guernsey, Channel Islands, United Kingdom - Guernsey"));
        AIRPORTS.add(new Results("GCK", "Garden City, KS, USA - Garden City Municipal Airport"));
        AIRPORTS.add(new Results("GCM", "Grand Cayman Island, Cayman Islands - Owen Roberts Intl Airport"));
        AIRPORTS.add(new Results("GCN", "Grand Canyon, AZ, USA"));
        AIRPORTS.add(new Results("GDL", "Guadalajara, Jalisco, Mexico - Miguel Hidalgo Intl"));
        AIRPORTS.add(new Results("GDN", "Gdansk, Poland - Rebiechowo"));
        AIRPORTS.add(new Results("GDT", "Grand Turk Is, Turks And Caicos Islands"));
        AIRPORTS.add(new Results("GDV", "Glendive, MT, USA"));
        AIRPORTS.add(new Results("GDX", "Magadan, Russia - Magadan"));
        AIRPORTS.add(new Results("GEG", "Spokane, WA, USA - International/Geiger Field"));
        AIRPORTS.add(new Results("GEN", "Oslo, Norway - Garderm O E N"));
        AIRPORTS.add(new Results("GEO", "Georgetown, Guyana - Timehri"));
        AIRPORTS.add(new Results("GET", "Geraldton, Western Australia, Australia - Geraldton"));
        AIRPORTS.add(new Results("GFK", "Grand Forks, ND, USA - Grand Forks International Airport"));
        AIRPORTS.add(new Results("GGG", "Longview/Gladewater/Kilgore, TX, USA - Gregg County"));
        AIRPORTS.add(new Results("GGT", "George Town, Bahamas - Exuma International"));
        AIRPORTS.add(new Results("GGW", "Glasgow, MT, USA"));
        AIRPORTS.add(new Results("GHB", "Governors Harbour, Bahamas"));
        AIRPORTS.add(new Results("GIB", "Gibraltar, Gibraltar - Gibraltar"));
        AIRPORTS.add(new Results("GIG", "Rio De Janeiro, Rio De Janeiro, Brazil - International Airport"));
        AIRPORTS.add(new Results("GJT", "Grand Junction, CO, USA - Walker Field"));
        AIRPORTS.add(new Results("GKA", "Goroka, Papua New Guinea - Goroka"));
        AIRPORTS.add(new Results("GLA", "Glasgow, Scotland, United Kingdom - Glasgow Scotland"));
        AIRPORTS.add(new Results("GLD", "Goodland, KS, USA - Renner Field"));
        AIRPORTS.add(new Results("GLF", "Golfito, Costa Rica - Golfito"));
        AIRPORTS.add(new Results("GLS", "Galveston, TX, USA - Scholes Field"));
        AIRPORTS.add(new Results("GLV", "Golovin, AK, USA"));
        AIRPORTS.add(new Results("GNB", "Grenoble, France - St Geoirs"));
        AIRPORTS.add(new Results("GND", "St Georges/Grenada, Grenada - Pt Saline"));
        AIRPORTS.add(new Results("GNV", "Gainesville, FL, USA - Jr Alison Municipal"));
        AIRPORTS.add(new Results("GOA", "Genoa, Italy - Christoforo Colombo"));
        AIRPORTS.add(new Results("GOH", "Nuuk, Greenland"));
        AIRPORTS.add(new Results("GOI", "Goa, India - Dabolim"));
        AIRPORTS.add(new Results("GOJ", "Nizhniy Novgorod, Russia - Nizhniy"));
        AIRPORTS.add(new Results("GON", "Groton / New London, CT, USA - Groton-New London"));
        AIRPORTS.add(new Results("GOT", "Gothenburg, Sweden - Landvetter"));
        AIRPORTS.add(new Results("GOV", "Gove, Northern Territory, Australia - Nhulunbuy"));
        AIRPORTS.add(new Results("GPS", "Galapagos Islands, Ecuador - Baltra"));
        AIRPORTS.add(new Results("GPT", "Gulfport, MS, USA - Gulfport/Biloxi"));
        AIRPORTS.add(new Results("GRB", "Green Bay, WI, USA - Austin/Straybel Field"));
        AIRPORTS.add(new Results("GRI", "Grand Island, NE, USA - Central Nebraska Regional Airport"));
        AIRPORTS.add(new Results("GRJ", "George, South Africa - George"));
        AIRPORTS.add(new Results("GRO", "Gerona, Spain - Costa Brava"));
        AIRPORTS.add(new Results("GRQ", "Groningen, Netherlands - Eelde"));
        AIRPORTS.add(new Results("GRR", "Grand Rapids, MI, USA - Kent County International Airport"));
        AIRPORTS.add(new Results("GRU", "Sao Paulo, Sao Paulo, Brazil - Guarulhos"));
        AIRPORTS.add(new Results("GRU", "Sao Paulo, Sao Paulo, Brazil - Guarulhos International"));
        AIRPORTS.add(new Results("GRX", "Granada, Spain - Granada"));
        AIRPORTS.add(new Results("GRZ", "Graz, Austria - Thalerhof"));
        AIRPORTS.add(new Results("GSO", "Greensboro / High Point, NC, USA - Piedmont Triad Intl Airport"));
        AIRPORTS.add(new Results("GTF", "Great Falls, MT, USA - Great Falls International"));
        AIRPORTS.add(new Results("GTO", "Gorontalo, Indonesia - Tolotio"));
        AIRPORTS.add(new Results("GTR", "Columbus, MS, USA - Golden"));
        AIRPORTS.add(new Results("GUA", "Guatemala City, Guatemala - La Aurora Intl Airport"));
        AIRPORTS.add(new Results("GUB", "Guerrero Negro, Baja California Sur, Mexico - Guerrero Negro Airport"));
        AIRPORTS.add(new Results("GUC", "Gunnison, CO, USA - Gunnison County Airport"));
        AIRPORTS.add(new Results("GUM", "Guam, Guam - Ab Wonpat Intl Airport"));
        AIRPORTS.add(new Results("GUP", "Gallup, NM, USA - Gallup Municipal"));
        AIRPORTS.add(new Results("GUR", "Alotau, Papua New Guinea - Gurney"));
        AIRPORTS.add(new Results("GVA", "Geneva, Switzerland - Geneva"));
        AIRPORTS.add(new Results("GWD", "Gwadar, Pakistan"));
        AIRPORTS.add(new Results("GWT", "Westerland, Germany - Westerland"));
        AIRPORTS.add(new Results("GWY", "Galway, Ireland - Carnmore"));
        AIRPORTS.add(new Results("GXQ", "Coyhaique, Chile - Teniente Vidal"));
        AIRPORTS.add(new Results("GYE", "Guayaquil, Ecuador - Simon Bolivar"));
        AIRPORTS.add(new Results("GYM", "Guaymas, Sonora, Mexico"));
        AIRPORTS.add(new Results("GYY", "Gary, IN, USA"));
        AIRPORTS.add(new Results("HAD", "Halmstad, Sweden - Halmstad"));
        AIRPORTS.add(new Results("HAG", "The Hague, Netherlands"));
        AIRPORTS.add(new Results("HAH", "Moroni (Hahaya), Comoros"));
        AIRPORTS.add(new Results("HAJ", "Hanover, Germany - Langenhagen"));
        AIRPORTS.add(new Results("HAK", "Haikou, China - Haikou"));
        AIRPORTS.add(new Results("HAM", "Hamburg, Germany - Fuhlsbuttel"));
        AIRPORTS.add(new Results("HAN", "Hanoi, Vietnam - Noibai Airport"));
        AIRPORTS.add(new Results("HAU", "Haugesund, Norway - Karmoy"));
        AIRPORTS.add(new Results("HAV", "Havana, Cuba - Jose Marti"));
        AIRPORTS.add(new Results("HBA", "Hobart, Tasmania, Australia - Hobart"));
        AIRPORTS.add(new Results("HDB", "Heidelberg, Germany"));
        AIRPORTS.add(new Results("HDN", "Hayden, CO, USA - Yampa Valley Regional Airport"));
        AIRPORTS.add(new Results("HDY", "Hat Yai, Thailand"));
        AIRPORTS.add(new Results("HEL", "Helsinki, Finland - Helsinki"));
        AIRPORTS.add(new Results("HER", "Heraklion, Crete Island, Greece - Heraklion"));
        AIRPORTS.add(new Results("HET", "Hohhot, China"));
        AIRPORTS.add(new Results("HFT", "Hammerfest, Norway"));
        AIRPORTS.add(new Results("HGH", "Hangzhou, China"));
        AIRPORTS.add(new Results("HGN", "Mae Hong Son, Thailand - Mae Hong Son"));
        AIRPORTS.add(new Results("HGR", "Hagerstown, MD, USA - Washington County Regional Airport"));
        AIRPORTS.add(new Results("HHH", "Hilton Head, SC, USA - Municipal"));
        AIRPORTS.add(new Results("HIB", "Hibbing / Chisholm, MN, USA - Hibbing-Chisholm"));
        AIRPORTS.add(new Results("HIJ", "Hiroshima, Japan - Hiroshima"));
        AIRPORTS.add(new Results("HIR", "Honiara/Guadalcanal, Solomon Islands - Henderson International"));
        AIRPORTS.add(new Results("HIS", "Hayman Island, Queensland, Australia - Hayman Island Airport"));
        AIRPORTS.add(new Results("HKD", "Hakodate, Japan - Hakodate"));
        AIRPORTS.add(new Results("HKG", "Hong Kong, Hong Kong"));
        AIRPORTS.add(new Results("HKK", "Hokitika, New Zealand - Hokitika"));
        AIRPORTS.add(new Results("HKN", "Hoskins, Papua New Guinea - Hoskins"));
        AIRPORTS.add(new Results("HKT", "Phuket, Thailand - Phuket"));
        AIRPORTS.add(new Results("HKY", "Hickory, NC, USA"));
        AIRPORTS.add(new Results("HLN", "Helena, MT, USA"));
        AIRPORTS.add(new Results("HLP", "Jakarta, Indonesia - Halim Perdana Kusama"));
        AIRPORTS.add(new Results("HLZ", "Hamilton, New Zealand - Hamilton"));
        AIRPORTS.add(new Results("HMA", "Malmo, Sweden - Malmo Harbour"));
        AIRPORTS.add(new Results("HMO", "Hermosillo, Sonora, Mexico - General Ignacio Pesqueira Garcia"));
        AIRPORTS.add(new Results("HNA", "Morioka, Japan - Hanamaki"));
        AIRPORTS.add(new Results("HNH", "Hoonah, AK, USA"));
        AIRPORTS.add(new Results("HNL", "Honolulu, HI, USA - Honolulu International"));
        AIRPORTS.add(new Results("HNS", "Haines, AK, USA"));
        AIRPORTS.add(new Results("HOB", "Hobbs, NM, USA - Lea County"));
        AIRPORTS.add(new Results("HOM", "Homer, AK, USA - Homer Airport"));
        AIRPORTS.add(new Results("HON", "Huron, SD, USA - Huron Regional Airport"));
        AIRPORTS.add(new Results("HOT", "Hot Springs, AR, USA - Memorial Field"));
        AIRPORTS.add(new Results("HOU", "Houston, TX, USA - Houston Hobby Airport"));
        AIRPORTS.add(new Results("HOU", "Houston, TX, USA - Houston Hobby Airport"));
        AIRPORTS.add(new Results("HPB", "Hooper Bay, AK, USA"));
        AIRPORTS.add(new Results("HPN", "Westchester County, NY, USA - Westchester County Airport"));
        AIRPORTS.add(new Results("HPV", "Kauai Island, HI, USA - Princeville"));
        AIRPORTS.add(new Results("HRB", "Harbin, China"));
        AIRPORTS.add(new Results("HRE", "Harare, Zimbabwe - Harare"));
        AIRPORTS.add(new Results("HRG", "Hurghada, Egypt"));
        AIRPORTS.add(new Results("HRK", "Kharkov, Ukraine - Kharkov"));
        AIRPORTS.add(new Results("HRL", "Harlingen, TX, USA"));
        AIRPORTS.add(new Results("HRO", "Harrison, AR, USA - Boone County"));
        AIRPORTS.add(new Results("HSI", "Hastings, NE, USA"));
        AIRPORTS.add(new Results("HSV", "Huntsville/Decatur, AL, USA - Huntsville-Madison County Jetplex"));
        AIRPORTS.add(new Results("HTI", "Hamilton Island, Queensland, Australia"));
        AIRPORTS.add(new Results("HTS", "Huntington / Ashland, WV, USA - Tri-State"));
        AIRPORTS.add(new Results("HUF", "Terre Haute, IN, USA - Hulman Field"));
        AIRPORTS.add(new Results("HUI", "Hue, Vietnam"));
        AIRPORTS.add(new Results("HUM", "Houma, LA, USA - Terrebonne"));
        AIRPORTS.add(new Results("HUN", "Hualien, Taiwan - Hualien"));
        AIRPORTS.add(new Results("HUX", "Huatulco, Oaxaca, Mexico"));
        AIRPORTS.add(new Results("HUY", "Humberside, England, United Kingdom - Humberside"));
        AIRPORTS.add(new Results("HVB", "Hervey Bay, Queensland, Australia"));
        AIRPORTS.add(new Results("HVN", "New Haven, CT, USA - Tweed New Haven"));
        AIRPORTS.add(new Results("HVR", "Havre, MT, USA - City County"));
        AIRPORTS.add(new Results("HWN", "Hwange National Park, Zimbabwe - Hwange National Park"));
        AIRPORTS.add(new Results("HYA", "Hyannis, MA, USA - Barnstable County"));
        AIRPORTS.add(new Results("HYD", "Hyderabad, India - Begumpet"));
        AIRPORTS.add(new Results("HYG", "Hydaburg, AK, USA"));
        AIRPORTS.add(new Results("HYS", "Hays, KS, USA - Hays Municipal Airport"));
        AIRPORTS.add(new Results("IAD", "Washington, DC, USA - Dulles"));
        AIRPORTS.add(new Results("IAD", "Washington, DC, USA - Washington-Dulles International"));
        AIRPORTS.add(new Results("IAH", "Houston, TX, USA"));
        AIRPORTS.add(new Results("IAH", "Houston, TX, USA - Houston Intercontinental"));
        AIRPORTS.add(new Results("IAS", "Iasi, Romania - Iasi"));
        AIRPORTS.add(new Results("IBZ", "Ibiza, Spain - Ibiza"));
        AIRPORTS.add(new Results("ICT", "Wichita, KS, USA - Mid-Continent Airport"));
        AIRPORTS.add(new Results("IDA", "Idaho Falls, ID, USA"));
        AIRPORTS.add(new Results("IEV", "Kiev, Ukraine - Zhulhany"));
        AIRPORTS.add(new Results("IFP", "Bullhead City, AZ, USA - Bullhead"));
        AIRPORTS.add(new Results("IGA", "Inagua, Bahamas"));
        AIRPORTS.add(new Results("IGM", "Kingman, AZ, USA - Mohave County"));
        AIRPORTS.add(new Results("IGR", "Iguazu, Misiones, Argentina - Iguazu International"));
        AIRPORTS.add(new Results("IGU", "Iguassu Falls, Parana, Brazil"));
        AIRPORTS.add(new Results("IJK", "Izhevsk, Russia"));
        AIRPORTS.add(new Results("IKT", "Irkutsk, Russia - Irkutsk"));
        AIRPORTS.add(new Results("ILE", "Killeen, TX, USA"));
        AIRPORTS.add(new Results("ILF", "Ilford, Manitoba, Canada"));
        AIRPORTS.add(new Results("ILI", "Iliamna, AK, USA"));
        AIRPORTS.add(new Results("ILM", "Wilmington, NC, USA - New Hanover County Airport"));
        AIRPORTS.add(new Results("ILO", "Iloilo, Philippines - Mandurriao"));
        AIRPORTS.add(new Results("ILQ", "Ilo, Moquegua, Peru - Ilo Airport"));
        AIRPORTS.add(new Results("ILY", "Islay, Scotland, United Kingdom - Glenegedale"));
        AIRPORTS.add(new Results("IMF", "Imphal, India - Municipal"));
        AIRPORTS.add(new Results("IMP", "Imperatriz, Maranhao, Brazil"));
        AIRPORTS.add(new Results("IMT", "Iron Mountain, MI, USA - Ford Airport"));
        AIRPORTS.add(new Results("IND", "Indianapolis, IN, USA - Indianapolis International Airport"));
        AIRPORTS.add(new Results("INL", "International Falls, MN, USA - Falls International"));
        AIRPORTS.add(new Results("INN", "Innsbruck, Austria - Kranebitten"));
        AIRPORTS.add(new Results("INT", "Winston-Salem, NC, USA - Smith Reynolds"));
        AIRPORTS.add(new Results("INU", "Nauru, Nauru"));
        AIRPORTS.add(new Results("INV", "Inverness, Scotland, United Kingdom - Inverness"));
        AIRPORTS.add(new Results("IOA", "Ioannina, Greece - Ioannina"));
        AIRPORTS.add(new Results("IOM", "Isle Of Man, Isle Of Man, United Kingdom - Ronaldsway"));
        AIRPORTS.add(new Results("IOS", "Ilheus, Bahia, Brazil - Eduardo Gomes"));
        AIRPORTS.add(new Results("IPC", "Easter Island, Chile - Mataveri"));
        AIRPORTS.add(new Results("IPH", "Ipoh, Malaysia - Ipoh"));
        AIRPORTS.add(new Results("IPI", "Ipiales, Colombia - San Luis"));
        AIRPORTS.add(new Results("IPT", "Williamsport, PA, USA - Williamsport Lycoming Municipal"));
        AIRPORTS.add(new Results("IQQ", "Iquique, Chile - Chucumata"));
        AIRPORTS.add(new Results("IQT", "Iquitos, Peru - Cf Secada"));
        AIRPORTS.add(new Results("ISB", "Islamabad, Pakistan - International"));
        AIRPORTS.add(new Results("ISC", "Isles Of Scilly, Isles Of Scilly, United Kingdom - Tresco"));
        AIRPORTS.add(new Results("ISN", "Williston, ND, USA - Sloulin Field International"));
        AIRPORTS.add(new Results("ISO", "Kinston, NC, USA"));
        AIRPORTS.add(new Results("ISP", "Islip, NY, USA - Long Island-Macarthur Airport"));
        AIRPORTS.add(new Results("IST", "Istanbul, Turkey - Ataturk"));
        AIRPORTS.add(new Results("ITH", "Ithaca, NY, USA - Tompkins County"));
        AIRPORTS.add(new Results("ITM", "Osaka, Japan - Itami International Was Osaka"));
        AIRPORTS.add(new Results("ITO", "Hilo, HI, USA - Hilo Hawaii:Hawaii-International Usa"));
        AIRPORTS.add(new Results("IWD", "Ironwood, MI, USA - Gogebic County Airport"));
        AIRPORTS.add(new Results("IXB", "Bagdogra, India - Bagdogra"));
        AIRPORTS.add(new Results("IXE", "Mangalore, India - Bajpe"));
        AIRPORTS.add(new Results("IXJ", "Jammu, India - Satwari"));
        AIRPORTS.add(new Results("IXM", "Madurai, India - Madurai"));
        AIRPORTS.add(new Results("IXU", "Aurangabad, India - Chikkalthana"));
        AIRPORTS.add(new Results("IXZ", "Port Blair, India - Port Blair"));
        AIRPORTS.add(new Results("IYK", "Inyokern, CA, USA - Inyokern Airport"));
        AIRPORTS.add(new Results("IZO", "Izumo, Japan"));
        AIRPORTS.add(new Results("JAC", "Jackson Hole, WY, USA - Jackson Hole Airport"));
        AIRPORTS.add(new Results("JAI", "Jaipur, India - Sanganeer"));
        AIRPORTS.add(new Results("JAN", "Jackson, MS, USA - Allen C Thompson Field"));
        AIRPORTS.add(new Results("JAT", "Jabat, Marshall Islands - Jabat Intl"));
        AIRPORTS.add(new Results("JAV", "Ilulissat, Greenland"));
        AIRPORTS.add(new Results("JAX", "Jacksonville, FL, USA - Jacksonville International Airport"));
        AIRPORTS.add(new Results("JBR", "Jonesboro, AR, USA - Municipal"));
        AIRPORTS.add(new Results("JCA", "Cannes, France - Mandelieu"));
        AIRPORTS.add(new Results("JDH", "Jodhpur, India"));
        AIRPORTS.add(new Results("JDP", "Paris, France - Issy Les Moulineaux"));
        AIRPORTS.add(new Results("JED", "Jeddah, Saudi Arabia - Jeddah International"));
        AIRPORTS.add(new Results("JER", "Jersey, Channel Islands, United Kingdom - States"));
        AIRPORTS.add(new Results("JFK", "New York, NY, USA - John F Kennedy Intl Airport"));
        AIRPORTS.add(new Results("JGA", "Jamnagar, India"));
        AIRPORTS.add(new Results("JHB", "Johor Bahru, Malaysia - Sultan Ismail International"));
        AIRPORTS.add(new Results("JHE", "Helsingborg, Sweden - Heliport"));
        AIRPORTS.add(new Results("JHM", "Kapalua, HI, USA - Kapalua"));
        AIRPORTS.add(new Results("JHW", "Jamestown, NY, USA - Chautauqua County Airport"));
        AIRPORTS.add(new Results("JIB", "Djibouti, Djibouti - Ambouli"));
        AIRPORTS.add(new Results("JKG", "Jonkoping, Sweden - Axamo"));
        AIRPORTS.add(new Results("JLN", "Joplin, MO, USA - Municipal Airport"));
        AIRPORTS.add(new Results("JMC", "Sausalito, CA, USA - Marin County"));
        AIRPORTS.add(new Results("JMK", "Mikonos, Greece - Mikonos"));
        AIRPORTS.add(new Results("JMM", "Malmo, Sweden - Malmo Harbour Heliport"));
        AIRPORTS.add(new Results("JMO", "Jomsom, Nepal"));
        AIRPORTS.add(new Results("JMS", "Jamestown, ND, USA - Jamestown Municipal Airport"));
        AIRPORTS.add(new Results("JNB", "Johannesburg, South Africa - Jan Smuts"));
        AIRPORTS.add(new Results("JNS", "Narssaq, Greenland"));
        AIRPORTS.add(new Results("JNU", "Juneau, AK, USA - Juneau"));
        AIRPORTS.add(new Results("JNX", "Naxos, Cyclades Islands, Greece - Naxos Airport"));
        AIRPORTS.add(new Results("JOG", "Yogyakarta, Indonesia"));
        AIRPORTS.add(new Results("JOI", "Joinville, Santa Catarina, Brazil - Federal"));
        AIRPORTS.add(new Results("JON", "Johnston Island, US, Outlying Islands"));
        AIRPORTS.add(new Results("JRA", "New York City, NY, USA"));
        AIRPORTS.add(new Results("JRO", "Kilimanjaro, Tanzania - Kilimanjaro"));
        AIRPORTS.add(new Results("JSI", "Skiathos, Greece - Skiathos"));
        AIRPORTS.add(new Results("JST", "Johnstown, PA, USA - Johnstown Cambria"));
        AIRPORTS.add(new Results("JTR", "Santorini/Thira Is, Greece - Santorini"));
        AIRPORTS.add(new Results("JUJ", "Jujuy, Provincia Jujuy, Argentina - El Cadillal"));
        AIRPORTS.add(new Results("JUL", "Juliaca, Peru - Juliaca"));
        AIRPORTS.add(new Results("KAB", "Kariba, Zimbabwe - Kariba"));
        AIRPORTS.add(new Results("KAE", "Kake, AK, USA"));
        AIRPORTS.add(new Results("KAL", "Kaltag, AK, USA"));
        AIRPORTS.add(new Results("KAN", "Kano, Nigeria - Aminu Kano International"));
        AIRPORTS.add(new Results("KAT", "Kaitaia, New Zealand - Kaitaia"));
        AIRPORTS.add(new Results("KBP", "Kiev, Ukraine - Borispol"));
        AIRPORTS.add(new Results("KBR", "Kota Bharu, Malaysia - Sultan Ismail Petra"));
        AIRPORTS.add(new Results("KCG", "Chignik, AK, USA - Fisheries"));
        AIRPORTS.add(new Results("KCH", "Kuching, Sarawak, Malaysia - Kuching"));
        AIRPORTS.add(new Results("KCL", "Chignik, AK, USA - Lagoon"));
        AIRPORTS.add(new Results("KEF", "Reykjavik, Iceland - Keflavik"));
        AIRPORTS.add(new Results("KEH", "Kenmore Air Harbor, WA, USA"));
        AIRPORTS.add(new Results("KEJ", "Kemerovo, Russia - Kemerovo"));
        AIRPORTS.add(new Results("KEL", "Kiel, Germany - Holtenau"));
        AIRPORTS.add(new Results("KEM", "Kemi/Tornio, Finland - Kemi"));
        AIRPORTS.add(new Results("KEP", "Nepalganj, Nepal - Nepalganj"));
        AIRPORTS.add(new Results("KER", "Kerman, Iran - Kerman"));
        AIRPORTS.add(new Results("KGC", "Kingscote, South Australia, Australia"));
        AIRPORTS.add(new Results("KGD", "Kaliningrad, Russia - Kaliningrad Airport"));
        AIRPORTS.add(new Results("KHH", "Kaohsiung, Taiwan"));
        AIRPORTS.add(new Results("KHI", "Karachi, Pakistan - Karachi"));
        AIRPORTS.add(new Results("KHV", "Khabarovsk, Russia - Novy"));
        AIRPORTS.add(new Results("KIN", "Kingston, Jamaica"));
        AIRPORTS.add(new Results("KIR", "Kerry County, Ireland - Kerry County"));
        AIRPORTS.add(new Results("KIV", "Kishinev, Moldova - Kishinev"));
        AIRPORTS.add(new Results("KIX", "Osaka, Japan - Kansai International"));
        AIRPORTS.add(new Results("KJA", "Krasnojarsk, Russia"));
        AIRPORTS.add(new Results("KKN", "Kirkenes, Norway - Hoeyburtmoen"));
        AIRPORTS.add(new Results("KLO", "Kalibo, Philippines - Kalibo"));
        AIRPORTS.add(new Results("KLR", "Kalmar, Sweden - Kalmar"));
        AIRPORTS.add(new Results("KLU", "Klagenfurt, Austria - Klagenfurt"));
        AIRPORTS.add(new Results("KLW", "Klawock, AK, USA"));
        AIRPORTS.add(new Results("KMG", "Kunming, China - Kunming"));
        AIRPORTS.add(new Results("KMI", "Miyazaki, Japan - Miyazaki"));
        AIRPORTS.add(new Results("KMJ", "Kumamoto, Japan - Kumamoto"));
        AIRPORTS.add(new Results("KNS", "King Island, Tasmania, Australia - King Island"));
        AIRPORTS.add(new Results("KOA", "Kona, HI, USA - Keahole"));
        AIRPORTS.add(new Results("KOI", "Kirkwall / Orkney Island, Scotland, United Kingdom - Kirkwall"));
        AIRPORTS.add(new Results("KOJ", "Kagoshima, Japan - Kagoshima"));
        AIRPORTS.add(new Results("KOK", "Kokkola/Pietarsaari, Finland - Kruunupyy"));
        AIRPORTS.add(new Results("KPN", "Kipnuk, AK, USA"));
        AIRPORTS.add(new Results("KPO", "Pohang, South Korea - Na"));
        AIRPORTS.add(new Results("KRF", "Kramfors, Sweden - Kramfors"));
        AIRPORTS.add(new Results("KRK", "Krakow, Poland - Balice"));
        AIRPORTS.add(new Results("KRN", "Kiruna, Sweden - Kiruna"));
        AIRPORTS.add(new Results("KRP", "Karup, Denmark - Karup"));
        AIRPORTS.add(new Results("KRR", "Krasnodar, Russia - Krasnodar"));
        AIRPORTS.add(new Results("KRS", "Kristiansand, Norway - Kjevik"));
        AIRPORTS.add(new Results("KRT", "Khartoum, Sudan - Civil"));
        AIRPORTS.add(new Results("KSA", "Kosrae, Caroline Islands, Micronesia"));
        AIRPORTS.add(new Results("KSC", "Kosice, Slovakia - Barca"));
        AIRPORTS.add(new Results("KSH", "Kermanshah, Iran - Bakhtaran Iran"));
        AIRPORTS.add(new Results("KSJ", "Kasos Island, Greece - Kasos Island"));
        AIRPORTS.add(new Results("KSU", "Kristiansund, Norway - Kvernberget"));
        AIRPORTS.add(new Results("KTM", "Kathmandu, Nepal - Tribhuvan"));
        AIRPORTS.add(new Results("KTN", "Ketchikan, AK, USA - Ketchikan International"));
        AIRPORTS.add(new Results("KTR", "Katherine, Northern Territory, Australia - Tindal"));
        AIRPORTS.add(new Results("KTW", "Katowice, Poland - Pyrzowice"));
        AIRPORTS.add(new Results("KUA", "Kuantan, Malaysia - Padang Geroda"));
        AIRPORTS.add(new Results("KUF", "Samara, Russia - Samara"));
        AIRPORTS.add(new Results("KUL", "Kuala Lumpur, Malaysia - Subang Kuala Lumpur International"));
        AIRPORTS.add(new Results("KUN", "Kaunas, Lithuania - Kaunas"));
        AIRPORTS.add(new Results("KUO", "Kuopio, Finland - Kuopio"));
        AIRPORTS.add(new Results("KUS", "Kulusuk, Greenland - Metropolitan Area"));
        AIRPORTS.add(new Results("KUV", "Kunsan, South Korea"));
        AIRPORTS.add(new Results("KVA", "Kavala, Greece - Kavala"));
        AIRPORTS.add(new Results("KWA", "Kwajalein, Marshall Islands"));
        AIRPORTS.add(new Results("KWI", "Kuwait, Kuwait - International"));
        AIRPORTS.add(new Results("KWL", "Guilin, China"));
        AIRPORTS.add(new Results("KZN", "Kazan, Russia - Kazan"));
        AIRPORTS.add(new Results("LAD", "Luanda, Angola - Fevereiro"));
        AIRPORTS.add(new Results("LAF", "Lafayette, IN, USA - Purdue University Airport"));
        AIRPORTS.add(new Results("LAN", "Lansing, MI, USA - Capital City Airport"));
        AIRPORTS.add(new Results("LAP", "La Paz, Baja California Sur, Mexico - Aeropuerto General Marquez De Leon"));
        AIRPORTS.add(new Results("LAR", "Laramie, WY, USA - General Brees Field"));
        AIRPORTS.add(new Results("LAS", "Las Vegas, NV, USA - Mccarran International Airport"));
        AIRPORTS.add(new Results("LAW", "Lawton, OK, USA - Municipal"));
        AIRPORTS.add(new Results("LAX", "Los Angeles, CA, USA - Los Angeles Intl Airport"));
        AIRPORTS.add(new Results("LAX", "Los Angeles, CA, USA - Los Angeles Intl Airport"));
        AIRPORTS.add(new Results("LBA", "Leeds/Bradford, England, United Kingdom"));
        AIRPORTS.add(new Results("LBB", "Lubbock, TX, USA - Lubbock International Airport"));
        AIRPORTS.add(new Results("LBE", "Latrobe, PA, USA - Westmoreland County"));
        AIRPORTS.add(new Results("LBF", "North Platte, NE, USA - Lee Bird Field"));
        AIRPORTS.add(new Results("LBL", "Liberal, KS, USA - Glenn L Martin Terminal"));
        AIRPORTS.add(new Results("LBU", "Labuan, Sabah, Malaysia"));
        AIRPORTS.add(new Results("LBV", "Libreville, Gabon - Libreville"));
        AIRPORTS.add(new Results("LCA", "Larnaca, Cyprus - Intl"));
        AIRPORTS.add(new Results("LCE", "La Ceiba, Honduras - International"));
        AIRPORTS.add(new Results("LCG", "La Coruna, Spain - La Coruna"));
        AIRPORTS.add(new Results("LCH", "Lake Charles, LA, USA - Municipal"));
        AIRPORTS.add(new Results("LCY", "London, England, United Kingdom - London City"));
        AIRPORTS.add(new Results("LDB", "Londrina, Parana, Brazil - Londrina"));
        AIRPORTS.add(new Results("LDE", "Lourdes/Tarbes, France - Tarbes International"));
        AIRPORTS.add(new Results("LDU", "Lahad Datu, Sabah, Malaysia - Lahad Datu"));
        AIRPORTS.add(new Results("LEA", "Learmonth, Western Australia, Australia"));
        AIRPORTS.add(new Results("LEB", "Lebanon/Hanover/White River, NH, USA - Lebanon Regional"));
        AIRPORTS.add(new Results("LED", "St Petersburg, Russia - Pulkovo"));
        AIRPORTS.add(new Results("LEH", "Le Havre, France - Le Havre"));
        AIRPORTS.add(new Results("LEI", "Almeria, Spain - Almeria"));
        AIRPORTS.add(new Results("LEJ", "Leipzig, Germany - Leipzig"));
        AIRPORTS.add(new Results("LET", "Leticia, Colombia - Gen Av Cob0"));
        AIRPORTS.add(new Results("LEX", "Lexington, KY, USA - Blue Grass Field"));
        AIRPORTS.add(new Results("LFT", "Lafayette / New Iberia, LA, USA - Municipal"));
        AIRPORTS.add(new Results("LFW", "Lome, Togo - Lome"));
        AIRPORTS.add(new Results("LGA", "New York, NY, USA - Laguardia"));
        AIRPORTS.add(new Results("LGB", "Long Beach, CA, USA - Long Beach Municipal Airport"));
        AIRPORTS.add(new Results("LGG", "Liege, Belgium - Bierset"));
        AIRPORTS.add(new Results("LGI", "Deadmans Cay / Long Island, Bahamas - Deadmans Cay"));
        AIRPORTS.add(new Results("LGK", "Langkawi, Malaysia"));
        AIRPORTS.add(new Results("LGP", "Legaspi, Philippines - Legaspi"));
        AIRPORTS.add(new Results("LGW", "London, England, United Kingdom - Gatwick"));
        AIRPORTS.add(new Results("LHE", "Lahore, Pakistan - Lahore"));
        AIRPORTS.add(new Results("LHR", "London, England, United Kingdom - Heathrow"));
        AIRPORTS.add(new Results("LIG", "Limoges, France - Bellegarde"));
        AIRPORTS.add(new Results("LIH", "Kauai Island, HI, USA - Lihue Municipal Airport"));
        AIRPORTS.add(new Results("LIM", "Lima, Peru - Intl Jorge Chavez"));
        AIRPORTS.add(new Results("LIN", "Milan, Italy - Linate"));
        AIRPORTS.add(new Results("LIR", "Liberia, Costa Rica - Liberia"));
        AIRPORTS.add(new Results("LIS", "Lisbon, Portugal - Lisboa"));
        AIRPORTS.add(new Results("LIT", "Little Rock, AR, USA - Little Rock Regional Airport"));
        AIRPORTS.add(new Results("LJU", "Ljubljana, Slovenia - Brnik"));
        AIRPORTS.add(new Results("LKE", "Seattle, WA, USA - Lake Union Sea Plane Base"));
        AIRPORTS.add(new Results("LKN", "Leknes, Norway - Leknes"));
        AIRPORTS.add(new Results("LKO", "Lucknow, India"));
        AIRPORTS.add(new Results("LLA", "Lulea, Sweden - Kallax"));
        AIRPORTS.add(new Results("LLW", "Lilongwe, Malawi - Kamuzu Intl"));
        AIRPORTS.add(new Results("LLY", "Mount Holly, NJ, USA - Mt Holly"));
        AIRPORTS.add(new Results("LMM", "Los Mochis, Sinaloa, Mexico"));
        AIRPORTS.add(new Results("LMN", "Limbang, Sarawak, Malaysia - Limbang"));
        AIRPORTS.add(new Results("LMT", "Klamath Falls, OR, USA - Kingsley Field Airport"));
        AIRPORTS.add(new Results("LNK", "Lincoln, NE, USA - Municipal Airport"));
        AIRPORTS.add(new Results("LNS", "Lancaster, PA, USA - Lancaster"));
        AIRPORTS.add(new Results("LNV", "Londolovit, Papua New Guinea - Londolovit"));
        AIRPORTS.add(new Results("LNY", "Lanai City, HI, USA - Lanai"));
        AIRPORTS.add(new Results("LNZ", "Linz, Austria - Linz"));
        AIRPORTS.add(new Results("LOS", "Lagos, Nigeria - Murtala Muhammed"));
        AIRPORTS.add(new Results("LOV", "Monclova, Coahuila, Mexico - Monclova Airport"));
        AIRPORTS.add(new Results("LPA", "Gran Canaria, Canary Islands, Spain - Aeropuerto De Gran Canaria"));
        AIRPORTS.add(new Results("LPB", "La Paz, Bolivia - El Alto"));
        AIRPORTS.add(new Results("LPI", "Linkoping, Sweden - Saab"));
        AIRPORTS.add(new Results("LPL", "Liverpool, England, United Kingdom - Liverpool"));
        AIRPORTS.add(new Results("LRD", "Laredo, TX, USA - International"));
        AIRPORTS.add(new Results("LRH", "La Rochelle, France - Laleu"));
        AIRPORTS.add(new Results("LRM", "Casa De Campo, Dominican Republic"));
        AIRPORTS.add(new Results("LRS", "Leros, Greece - Leros"));
        AIRPORTS.add(new Results("LRT", "Lorient, France - Lann-Bihoue"));
        AIRPORTS.add(new Results("LRU", "Las Cruces, NM, USA"));
        AIRPORTS.add(new Results("LSC", "La Serena, Chile - La Florida"));
        AIRPORTS.add(new Results("LSE", "La Crosse, WI, USA - La Crosse Municipal"));
        AIRPORTS.add(new Results("LSI", "Shetland Islands /Shetland Isd, Scotland, United Kingdom - Shetland Islands"));
        AIRPORTS.add(new Results("LSP", "Las Piedras, Venezuela - Josefa Camejo"));
        AIRPORTS.add(new Results("LSQ", "Los Angeles, Chile - Maria Dolores"));
        AIRPORTS.add(new Results("LSS", "Terre-De-Haut, Guadeloupe"));
        AIRPORTS.add(new Results("LST", "Launceston, Tasmania, Australia - Launceston"));
        AIRPORTS.add(new Results("LSY", "Lismore, New South Wales, Australia - Lismore"));
        AIRPORTS.add(new Results("LTN", "London, England, United Kingdom - Luton International"));
        AIRPORTS.add(new Results("LTO", "Loreto, Baja California Sur, Mexico"));
        AIRPORTS.add(new Results("LUA", "Lukla, Nepal - Lukla"));
        AIRPORTS.add(new Results("LUD", "Luderitz, Namibia - Luderitz"));
        AIRPORTS.add(new Results("LUG", "Lugano, Switzerland - Agno"));
        AIRPORTS.add(new Results("LUN", "Lusaka, Zambia - Lusaka"));
        AIRPORTS.add(new Results("LUX", "Luxembourg, Luxembourg - Findel"));
        AIRPORTS.add(new Results("LVI", "Livingstone, Zambia - Livingstone"));
        AIRPORTS.add(new Results("LWB", "Greenbrier, WV, USA - Greenbrier Valley Airport"));
        AIRPORTS.add(new Results("LWK", "Shetland Islands /Shetland Isd, Scotland, United Kingdom - Tingwall"));
        AIRPORTS.add(new Results("LWO", "Lvov, Ukraine - Snilow"));
        AIRPORTS.add(new Results("LWS", "Lewiston, ID, USA - Lewiston-Nez Perce Airport"));
        AIRPORTS.add(new Results("LWT", "Lewistown, MT, USA - Municipal"));
        AIRPORTS.add(new Results("LWY", "Lawas, Sarawak, Malaysia - Lawas"));
        AIRPORTS.add(new Results("LXR", "Luxor, Egypt - Luxor"));
        AIRPORTS.add(new Results("LYH", "Lynchburg, VA, USA - Municipal Airport"));
        AIRPORTS.add(new Results("LYP", "Faisalabad, Pakistan - Lyallpur"));
        AIRPORTS.add(new Results("LYR", "Longyearbyen, Norway - Svalbard"));
        AIRPORTS.add(new Results("LYS", "Lyon, France - Satolas"));
        AIRPORTS.add(new Results("LZC", "Lazaro Cardenas, Michoacan, Mexico - Na"));
        AIRPORTS.add(new Results("MAA", "Madras, India - Meenambarkkam"));
        AIRPORTS.add(new Results("MAD", "Madrid, Spain - Barajas"));
        AIRPORTS.add(new Results("MAF", "Midland/Odessa, TX, USA - Midland Intl Airport"));
        AIRPORTS.add(new Results("MAG", "Madang, Papua New Guinea - Madang"));
        AIRPORTS.add(new Results("MAH", "Menorca, Spain - Aerop De Menorca"));
        AIRPORTS.add(new Results("MAJ", "Majuro, Marshall Islands - International"));
        AIRPORTS.add(new Results("MAM", "Matamoros, Tamaulipas, Mexico - Servando Canales"));
        AIRPORTS.add(new Results("MAN", "Manchester, England, United Kingdom - International"));
        AIRPORTS.add(new Results("MAO", "Manaus, Amazonas, Brazil - Eduardo Gomes"));
        AIRPORTS.add(new Results("MAR", "Maracaibo, Venezuela - La Chinita"));
        AIRPORTS.add(new Results("MAY", "Mangrove Cay, Bahamas"));
        AIRPORTS.add(new Results("MAZ", "Mayaguez, PR, USA - El Maui"));
        AIRPORTS.add(new Results("MBA", "Mombasa, Kenya - Moi International"));
        AIRPORTS.add(new Results("MBJ", "Montego Bay, Jamaica - Sangster"));
        AIRPORTS.add(new Results("MBL", "Manistee, MI, USA - Manistee Blacker Airport"));
        AIRPORTS.add(new Results("MBS", "Midland / Bay City / Saginaw, MI, USA - Tri-City Airport"));
        AIRPORTS.add(new Results("MCG", "Mc Grath, AK, USA - Mc Grath"));
        AIRPORTS.add(new Results("MCI", "Kansas City, MO, USA - Kansas City International Airport"));
        AIRPORTS.add(new Results("MCK", "Mc Cook, NE, USA - Municipal"));
        AIRPORTS.add(new Results("MCM", "Monte Carlo, Monaco - Hel De Monte Carlo"));
        AIRPORTS.add(new Results("MCN", "Macon, GA, USA - Lewis B Wilson"));
        AIRPORTS.add(new Results("MCO", "Orlando, FL, USA - Orlando International Airport"));
        AIRPORTS.add(new Results("MCP", "Macapa, Amapa, Brazil"));
        AIRPORTS.add(new Results("MCT", "Muscat, Oman - Seeb"));
        AIRPORTS.add(new Results("MCW", "Mason City, IA, USA - Mason City Municipal Airport"));
        AIRPORTS.add(new Results("MCY", "Sunshine Coast, Queensland, Australia - Maroochydore"));
        AIRPORTS.add(new Results("MDC", "Manado, Indonesia - Samratulang"));
        AIRPORTS.add(new Results("MDE", "Medellin, Colombia - La Playas"));
        AIRPORTS.add(new Results("MDH", "Carbondale, IL, USA - Southern Illinois Airport"));
        AIRPORTS.add(new Results("MDQ", "Mar Del Plata, Buenos Aires, Argentina"));
        AIRPORTS.add(new Results("MDT", "Harrisburg, PA, USA - Harrisburg International Airport"));
        AIRPORTS.add(new Results("MDW", "Chicago, IL, USA - Midway"));
        AIRPORTS.add(new Results("MDZ", "Mendoza, Mendoza, Argentina - El Plumerillo"));
        AIRPORTS.add(new Results("MED", "Medinah, Saudi Arabia - Madinah-Prince Mohammad Bin Abdulaziz"));
        AIRPORTS.add(new Results("MEI", "Meridian, MS, USA - Key Field"));
        AIRPORTS.add(new Results("MEL", "Melbourne, Victoria, Australia - Tullamarine"));
        AIRPORTS.add(new Results("MEM", "Memphis, TN, USA - Memphis International Airport"));
        AIRPORTS.add(new Results("MES", "Medan, Indonesia - Polonia"));
        AIRPORTS.add(new Results("MEX", "Mexico City, Distrito Federal, Mexico - Juarez Intl Airport"));
        AIRPORTS.add(new Results("MEY", "Meghauli, Nepal - Meghauli"));
        AIRPORTS.add(new Results("MFE", "Mc Allen/Mission, TX, USA"));
        AIRPORTS.add(new Results("MFN", "Milford Sound, New Zealand"));
        AIRPORTS.add(new Results("MFR", "Medford, OR, USA - Medford-Jackson County Airport"));
        AIRPORTS.add(new Results("MGA", "Managua, Nicaragua"));
        AIRPORTS.add(new Results("MGM", "Montgomery, AL, USA - Dannelly Field"));
        AIRPORTS.add(new Results("MGQ", "Mogadishu, Somalia"));
        AIRPORTS.add(new Results("MGW", "Morgantown, WV, USA - Morgantown Municipal Airport"));
        AIRPORTS.add(new Results("MHH", "Marsh Harbour, Bahamas"));
        AIRPORTS.add(new Results("MHK", "Manhattan, KS, USA - Manhattan Municipal"));
        AIRPORTS.add(new Results("MHQ", "Mariehamn, Aland Island, Finland"));
        AIRPORTS.add(new Results("MHT", "Manchester, NH, USA - Manchester"));
        AIRPORTS.add(new Results("MIA", "Miami, FL, USA - Miami International Airport"));
        AIRPORTS.add(new Results("MID", "Merida, Yucatan, Mexico - Merida Internationl"));
        AIRPORTS.add(new Results("MIE", "Muncie, IN, USA - Delaware County Airport"));
        AIRPORTS.add(new Results("MIR", "Monastir, Tunisia - Skanes"));
        AIRPORTS.add(new Results("MJT", "Mytilene, Greece - Mytilene"));
        AIRPORTS.add(new Results("MJV", "Murcia, Spain - San Javier"));
        AIRPORTS.add(new Results("MKC", "Kansas City, MO, USA - Downtown"));
        AIRPORTS.add(new Results("MKE", "Milwaukee, WI, USA - General Mitchell Field"));
        AIRPORTS.add(new Results("MKG", "Muskegon, MI, USA - Muskegon County Intl Airport"));
        AIRPORTS.add(new Results("MKK", "Hoolehua, HI, USA - Municipal"));
        AIRPORTS.add(new Results("MKL", "Jackson, TN, USA - Mc Kellar Field"));
        AIRPORTS.add(new Results("MKM", "Mukah, Sarawak, Malaysia"));
        AIRPORTS.add(new Results("MKW", "Manokwari, Indonesia - Rendani"));
        AIRPORTS.add(new Results("MKY", "Mackay, Queensland, Australia - Mackay"));
        AIRPORTS.add(new Results("MLA", "Malta, Malta - Luqa"));
        AIRPORTS.add(new Results("MLB", "Melbourne, FL, USA - Melbourne Regional Airport"));
        AIRPORTS.add(new Results("MLE", "Male, Maldives - Male International"));
        AIRPORTS.add(new Results("MLG", "Malang, Indonesia"));
        AIRPORTS.add(new Results("MLH", "Mulhouse, France - Mulhouse"));
        AIRPORTS.add(new Results("MLI", "Moline, IL, USA - Quad City Airport"));
        AIRPORTS.add(new Results("MLM", "Morelia, Michoacan, Mexico - Municipal"));
        AIRPORTS.add(new Results("MLO", "Milos, Greece - Milos"));
        AIRPORTS.add(new Results("MLS", "Miles City, MT, USA - Miles City"));
        AIRPORTS.add(new Results("MLU", "Monroe, LA, USA"));
        AIRPORTS.add(new Results("MMB", "Memanbetsu, Japan"));
        AIRPORTS.add(new Results("MME", "Teesside, England, United Kingdom - Tees-Side"));
        AIRPORTS.add(new Results("MMH", "Mammoth Lakes, CA, USA - Mammoth Lakes Airport"));
        AIRPORTS.add(new Results("MMK", "Murmansk, Russia - Murmansk"));
        AIRPORTS.add(new Results("MMU", "Morristown, NJ, USA - Morristown"));
        AIRPORTS.add(new Results("MMX", "Malmo, Sweden - Sturup"));
        AIRPORTS.add(new Results("MNI", "Montserrat, Montserrat - Blackburne"));
        AIRPORTS.add(new Results("MNL", "Manila, Philippines - Ninoy Aquino International"));
        AIRPORTS.add(new Results("MNM", "Menominee, MI, USA - Twin County Airport"));
        AIRPORTS.add(new Results("MOB", "Mobile, AL, USA - Mobile Municipal"));
        AIRPORTS.add(new Results("MOD", "Modesto, CA, USA - Harry Sham Feild"));
        AIRPORTS.add(new Results("MOL", "Molde, Norway - Aro"));
        AIRPORTS.add(new Results("MOT", "Minot, ND, USA - Minot International Airport"));
        AIRPORTS.add(new Results("MOW", "Moscow, Russia"));
        AIRPORTS.add(new Results("MPA", "Mpacha, Namibia"));
        AIRPORTS.add(new Results("MPB", "Miami, FL, USA - Miami Public Seaplane Base"));
        AIRPORTS.add(new Results("MPL", "Montpellier, France - Frejorgues"));
        AIRPORTS.add(new Results("MPM", "Maputo, Mozambique - Maputo International"));
        AIRPORTS.add(new Results("MQL", "Mildura, Victoria, Australia - Mildura"));
        AIRPORTS.add(new Results("MQN", "Mo I Rana, Norway - Rossvoll"));
        AIRPORTS.add(new Results("MQT", "Marquette, MI, USA - Marquette County Airport"));
        AIRPORTS.add(new Results("MRD", "Merida, Venezuela - Alberto Carnevalli"));
        AIRPORTS.add(new Results("MRK", "Marco Island, FL, USA"));
        AIRPORTS.add(new Results("MRS", "Marseille, France - Marseille-Provence"));
        AIRPORTS.add(new Results("MRU", "Mauritius, Mauritius - Plaisance"));
        AIRPORTS.add(new Results("MRY", "Monterey / Carmel, CA, USA - Monterey Peninsula Airport"));
        AIRPORTS.add(new Results("MSJ", "Misawa, Japan"));
        AIRPORTS.add(new Results("MSL", "Muscle Shoals / Florence / Sheffield, AL, USA - Muscle Shoals"));
        AIRPORTS.add(new Results("MSN", "Madison, WI, USA - Dane County Regional Airport"));
        AIRPORTS.add(new Results("MSO", "Missoula, MT, USA - Missoula International"));
        AIRPORTS.add(new Results("MSP", "Minneapolis, MN, USA - Minneapolis/St Paul Intl Airport"));
        AIRPORTS.add(new Results("MSQ", "Minsk, Belarus - Minsk"));
        AIRPORTS.add(new Results("MSS", "Massena, NY, USA"));
        AIRPORTS.add(new Results("MST", "Maastricht, Netherlands - Zuid-Limburg"));
        AIRPORTS.add(new Results("MSU", "Maseru, Lesotho - Maseru"));
        AIRPORTS.add(new Results("MSY", "New Orleans, LA, USA - Moisant International Airport"));
        AIRPORTS.add(new Results("MTH", "Marathon, FL, USA"));
        AIRPORTS.add(new Results("MTJ", "Montrose, CO, USA - Montrose County Airport"));
        AIRPORTS.add(new Results("MTY", "Monterrey, Nuevo Leon, Mexico - Escobedo"));
        AIRPORTS.add(new Results("MUB", "Maun, Botswana"));
        AIRPORTS.add(new Results("MUC", "Munich, Germany - Franz Josef Strauss"));
        AIRPORTS.add(new Results("MUN", "Maturin, Venezuela"));
        AIRPORTS.add(new Results("MVD", "Montevideo, Uruguay - Carrasco"));
        AIRPORTS.add(new Results("MVN", "Mount Vernon, IL, USA - Mount Vernon Outland Airport"));
        AIRPORTS.add(new Results("MVY", "Marthas Vineyard, MA, USA"));
        AIRPORTS.add(new Results("MWA", "Marion, IL, USA"));
        AIRPORTS.add(new Results("MXL", "Mexicali, Baja California, Mexico - Rodolfo Sanchez Taboada"));
        AIRPORTS.add(new Results("MXP", "Milan, Italy - Malpensa"));
        AIRPORTS.add(new Results("MYA", "Moruya, New South Wales, Australia - Moruya"));
        AIRPORTS.add(new Results("MYJ", "Matsuyama, Japan - Matsuyama"));
        AIRPORTS.add(new Results("MYR", "Myrtle Beach, SC, USA"));
        AIRPORTS.add(new Results("MYY", "Miri, Sarawak, Malaysia - Miri"));
        AIRPORTS.add(new Results("MZL", "Manizales, Colombia - Santaguida"));
        AIRPORTS.add(new Results("MZT", "Mazatlan, Sinaloa, Mexico - Buelna"));
        AIRPORTS.add(new Results("MZV", "Mulu, Malaysia - Mulu Airport"));
        AIRPORTS.add(new Results("NAG", "Nagpur, India - Sonegaon"));
        AIRPORTS.add(new Results("NAH", "Naha, Indonesia"));
        AIRPORTS.add(new Results("NAK", "Nakhon Ratchasima, Thailand - Nakhon Ratchasima"));
        AIRPORTS.add(new Results("NAN", "Nadi, Fiji - International"));
        AIRPORTS.add(new Results("NAP", "Naples, Italy - Capodichino"));
        AIRPORTS.add(new Results("NAS", "Nassau, Bahamas - Nassau International Airport"));
        AIRPORTS.add(new Results("NAT", "Natal, Rio Grande Do Norte, Brazil - Agusto Severo"));
        AIRPORTS.add(new Results("NAY", "Beijing, China"));
        AIRPORTS.add(new Results("NBO", "Nairobi, Kenya - Jomo Kenyatta Internatonal"));
        AIRPORTS.add(new Results("NCA", "North Caicos, Turks And Caicos Islands"));
        AIRPORTS.add(new Results("NCE", "Nice, France - Cote D'azur"));
        AIRPORTS.add(new Results("NCL", "Newcastle, England, United Kingdom - International"));
        AIRPORTS.add(new Results("NCY", "Annecy, France - Annecy-Meythe"));
        AIRPORTS.add(new Results("NDJ", "N Djamena, Chad - N'djamena"));
        AIRPORTS.add(new Results("NEC", "Necochea, Buenos Aires, Argentina - Necochea"));
        AIRPORTS.add(new Results("NEV", "Nevis, Leeward Islands, Saint Kitts And Nevis"));
        AIRPORTS.add(new Results("NGO", "Nagoya, Japan - Komaki"));
        AIRPORTS.add(new Results("NGS", "Nagasaki, Japan - Nagasaki"));
        AIRPORTS.add(new Results("NJC", "Nizhnevartovsk, Russia - Nizhnevartovsk"));
        AIRPORTS.add(new Results("NKC", "Nouakchott, Mauritania - Nouakchott"));
        AIRPORTS.add(new Results("NKG", "Nanjing, China"));
        AIRPORTS.add(new Results("NLA", "Ndola, Zambia - Ndola"));
        AIRPORTS.add(new Results("NLD", "Nuevo Laredo, Tamaulipas, Mexico"));
        AIRPORTS.add(new Results("NLP", "Nelspruit, South Africa"));
        AIRPORTS.add(new Results("NNG", "Nanning, China"));
        AIRPORTS.add(new Results("NOC", "Connaught, Ireland - Rep Of Ireland"));
        AIRPORTS.add(new Results("NOU", "Noumea, New Caledonia - Tontouta"));
        AIRPORTS.add(new Results("NPL", "New Plymouth, New Zealand - New Plymouth"));
        AIRPORTS.add(new Results("NQY", "Newquay, England, United Kingdom - Newquay Civil"));
        AIRPORTS.add(new Results("NRT", "Tokyo, Japan - Narita"));
        AIRPORTS.add(new Results("NRT", "Tokyo, Japan"));
        AIRPORTS.add(new Results("NSB", "Bimini, Bahamas - North Seaplane Base"));
        AIRPORTS.add(new Results("NSI", "Yaounde, Cameroon - Nsimalen"));
        AIRPORTS.add(new Results("NSN", "Nelson, New Zealand - Nelson"));
        AIRPORTS.add(new Results("NTE", "Nantes, France - Nantes-Chateau Bougon"));
        AIRPORTS.add(new Results("NTL", "Newcastle, New South Wales, Australia - Williamtown"));
        AIRPORTS.add(new Results("NUE", "Nuremberg, Germany - Nuremberg"));
        AIRPORTS.add(new Results("NVT", "Navegantes, Santa Catarina, Brazil"));
        AIRPORTS.add(new Results("NWA", "Moheli, Comoros"));
        AIRPORTS.add(new Results("NWI", "Norwich, England, United Kingdom - Norwich"));
        AIRPORTS.add(new Results("OAG", "Orange, New South Wales, Australia - Springhill"));
        AIRPORTS.add(new Results("OAJ", "Jacksonville, NC, USA"));
        AIRPORTS.add(new Results("OAK", "Oakland, CA, USA - Metropolitan Oakland Intl Apt"));
        AIRPORTS.add(new Results("OAX", "Oaxaca, Oaxaca, Mexico - Xoxocotlan"));
        AIRPORTS.add(new Results("OBO", "Obihiro, Japan - Obihiro"));
        AIRPORTS.add(new Results("ODE", "Odense, Denmark - Odense"));
        AIRPORTS.add(new Results("ODS", "Odessa, Ukraine - Central"));
        AIRPORTS.add(new Results("ODW", "Oak Harbor, WA, USA"));
        AIRPORTS.add(new Results("OFK", "Norfolk, NE, USA - Karl Stefan Memorial Airport"));
        AIRPORTS.add(new Results("OGG", "Kahului, HI, USA - Kahului Airport"));
        AIRPORTS.add(new Results("OGS", "Ogdensburg, NY, USA"));
        AIRPORTS.add(new Results("OHD", "Ohrid, Macedonia - Ohrid"));
        AIRPORTS.add(new Results("OIT", "Oita, Japan - Oita"));
        AIRPORTS.add(new Results("OKA", "Okinawa, Ryukyu Islands, Japan - Naha Field"));
        AIRPORTS.add(new Results("OKC", "Oklahoma City, OK, USA - Will Rogers World Airport"));
        AIRPORTS.add(new Results("OKJ", "Okayama, Japan - Okayama"));
        AIRPORTS.add(new Results("OLF", "Wolf Point, MT, USA"));
        AIRPORTS.add(new Results("OMA", "Omaha, NE, USA - Eppley Airfield"));
        AIRPORTS.add(new Results("OME", "Nome, AK, USA"));
        AIRPORTS.add(new Results("OMR", "Oradea, Romania - Oradea"));
        AIRPORTS.add(new Results("ONG", "Mornington, Queensland, Australia - Mornington Is"));
        AIRPORTS.add(new Results("ONT", "Ontario, CA, USA - Ontario International"));
        AIRPORTS.add(new Results("OOK", "Toksook Bay, AK, USA"));
        AIRPORTS.add(new Results("OOL", "Gold Coast, Queensland, Australia - Coolangatta"));
        AIRPORTS.add(new Results("OOM", "Cooma, New South Wales, Australia"));
        AIRPORTS.add(new Results("OPF", "Miami, FL, USA - Opa Locka"));
        AIRPORTS.add(new Results("OPO", "Porto, Portugal - Porto"));
        AIRPORTS.add(new Results("ORB", "Orebro, Sweden - Orebro"));
        AIRPORTS.add(new Results("ORD", "Chicago, IL, USA - O'hare International Airport"));
        AIRPORTS.add(new Results("ORF", "Norfolk, VA, USA - Norfolk International Airport"));
        AIRPORTS.add(new Results("ORH", "Worcester, MA, USA - Worcester /James D O'brien Field"));
        AIRPORTS.add(new Results("ORK", "Cork, Ireland - Cork"));
        AIRPORTS.add(new Results("ORL", "Orlando, FL, USA - Herndon"));
        AIRPORTS.add(new Results("ORN", "Oran, Algeria - Es Senia"));
        AIRPORTS.add(new Results("ORY", "Paris, France - Orly"));
        AIRPORTS.add(new Results("OSA", "Osaka, Japan - Osaka International"));
        AIRPORTS.add(new Results("OSD", "Ostersund, Sweden - Froesoe"));
        AIRPORTS.add(new Results("OSH", "Oshkosh, WI, USA - Wittman Field"));
        AIRPORTS.add(new Results("OTH", "North Bend, OR, USA"));
        AIRPORTS.add(new Results("OTM", "Ottumwa, IA, USA - Ottumwa Industrial Airport"));
        AIRPORTS.add(new Results("OTP", "Bucharest, Romania - Otopeni"));
        AIRPORTS.add(new Results("OTZ", "Kotzebue, AK, USA"));
        AIRPORTS.add(new Results("OUA", "Ouagadougou, Burkina Faso - Ouagadougou"));
        AIRPORTS.add(new Results("OUL", "Oulu, Finland - Oulu"));
        AIRPORTS.add(new Results("OVB", "Novosibirsk, Russia - Tolmachevo"));
        AIRPORTS.add(new Results("OVD", "Asturias, Spain - Asturias"));
        AIRPORTS.add(new Results("OWB", "Owensboro, KY, USA"));
        AIRPORTS.add(new Results("OWD", "Norwood, MA, USA - Memorial Code: Owd"));
        AIRPORTS.add(new Results("OXB", "Bissau, Guinea-Bissau - Osvaldo Vieira"));
        AIRPORTS.add(new Results("OXR", "Oxnard / Ventura, CA, USA - Oxnard Airport"));
        AIRPORTS.add(new Results("OZZ", "Ouarzazate, Morocco - Ouarzazate"));
        AIRPORTS.add(new Results("PAD", "Paderborn, Germany - Paderborn"));
        AIRPORTS.add(new Results("PAH", "Paducah, KY, USA"));
        AIRPORTS.add(new Results("PAP", "Port Au Prince, Haiti - Mais Gate"));
        AIRPORTS.add(new Results("PAR", "Paris, France"));
        AIRPORTS.add(new Results("PAS", "Paros, Greece - Paros Community"));
        AIRPORTS.add(new Results("PAT", "Patna, India - Patna"));
        AIRPORTS.add(new Results("PAZ", "Poza Rica, Veracruz, Mexico"));
        AIRPORTS.add(new Results("PBC", "Puebla, Puebla, Mexico"));
        AIRPORTS.add(new Results("PBI", "West Palm Beach, FL, USA - Palm Beach International Airport"));
        AIRPORTS.add(new Results("PBM", "Paramaribo, Suriname - Zanderij Intl"));
        AIRPORTS.add(new Results("PBO", "Paraburdoo, Western Australia, Australia - Paraburdoo"));
        AIRPORTS.add(new Results("PCL", "Pucallpa, Peru - Captain Rolden"));
        AIRPORTS.add(new Results("PCT", "Princeton, NJ, USA - Princeton Municipal"));
        AIRPORTS.add(new Results("PDG", "Padang, Indonesia - Tabing"));
        AIRPORTS.add(new Results("PDL", "Ponta Delgada, Azores Islands, Portugal - Nordela"));
        AIRPORTS.add(new Results("PDT", "Pendleton, OR, USA"));
        AIRPORTS.add(new Results("PDX", "Portland, OR, USA - Portland International Airport"));
        AIRPORTS.add(new Results("PEE", "Perm, Russia - Perm"));
        AIRPORTS.add(new Results("PEG", "Perugia, Italy - Na"));
        AIRPORTS.add(new Results("PEI", "Pereira, Colombia - Matecana"));
        AIRPORTS.add(new Results("PEK", "Beijing, China - Peking Capital Airport"));
        AIRPORTS.add(new Results("PEN", "Penang, Malaysia - Penang International"));
        AIRPORTS.add(new Results("PER", "Perth, Western Australia, Australia - Perth"));
        AIRPORTS.add(new Results("PES", "Petrozavodsk, Russia - Petrozavodsk Airport"));
        AIRPORTS.add(new Results("PEW", "Peshawar, Pakistan - Peshawar"));
        AIRPORTS.add(new Results("PFN", "Panama City, FL, USA"));
        AIRPORTS.add(new Results("PFO", "Paphos, Cyprus - International"));
        AIRPORTS.add(new Results("PGA", "Page, AZ, USA"));
        AIRPORTS.add(new Results("PGF", "Perpignan, France - Llabanere"));
        AIRPORTS.add(new Results("PGV", "Greenville, NC, USA"));
        AIRPORTS.add(new Results("PGX", "Perigueux, France"));
        AIRPORTS.add(new Results("PHE", "Port Hedland, Western Australia, Australia - Port Hedlan"));
        AIRPORTS.add(new Results("PHF", "Newport News/Williamsburg/Hampton, VA, USA - Patrick Henry Intl"));
        AIRPORTS.add(new Results("PHL", "Philadelphia, PA, USA - Philadelphia International Airport"));
        AIRPORTS.add(new Results("PHO", "Point Hope, AK, USA - Point Hope"));
        AIRPORTS.add(new Results("PHS", "Phitsanulok, Thailand"));
        AIRPORTS.add(new Results("PHX", "Phoenix, AZ, USA - Sky Harbor International Airport"));
        AIRPORTS.add(new Results("PIA", "Peoria, IL, USA - Greater Peoria Airport"));
        AIRPORTS.add(new Results("PIB", "Laurel, MS, USA - Laurel Hattiesburg/Camp Shelby"));
        AIRPORTS.add(new Results("PID", "Nassau, Bahamas - Paradise Island"));
        AIRPORTS.add(new Results("PIE", "St Petersburg/Clearwater, FL, USA - St Petersburg/Clearwater Intl"));
        AIRPORTS.add(new Results("PIH", "Pocatello, ID, USA"));
        AIRPORTS.add(new Results("PIK", "Glasgow, Scotland, United Kingdom - Prestwick"));
        AIRPORTS.add(new Results("PIR", "Pierre, SD, USA - Pierre Municipal Airport"));
        AIRPORTS.add(new Results("PIT", "Pittsburgh, PA, USA - Greater Pit Intnl Airport"));
        AIRPORTS.add(new Results("PIW", "Pikwitonei, Manitoba, Canada"));
        AIRPORTS.add(new Results("PJG", "Panjgur, Pakistan"));
        AIRPORTS.add(new Results("PKB", "Parkersburg / Marietta, WV, USA - Wood County"));
        AIRPORTS.add(new Results("PKC", "Petropavlovsk-Kamchatsky, Russia - Petropavlovsk-Kamchatsky"));
        AIRPORTS.add(new Results("PKE", "Parkes, New South Wales, Australia - Parkes"));
        AIRPORTS.add(new Results("PKR", "Pokhara, Nepal - Pokhara"));
        AIRPORTS.add(new Results("PKU", "Pekanbaru, Indonesia - Simpang Tiga"));
        AIRPORTS.add(new Results("PLB", "Plattsburgh, NY, USA"));
        AIRPORTS.add(new Results("PLH", "Plymouth, England, United Kingdom - Plymouth Airport"));
        AIRPORTS.add(new Results("PLM", "Palembang, Indonesia - Sultan Mahmud Badaruddin Ii"));
        AIRPORTS.add(new Results("PLN", "Pellston, MI, USA - Pellston Regional Airport"));
        AIRPORTS.add(new Results("PLO", "Port Lincoln, South Australia, Australia - Port Lincoln"));
        AIRPORTS.add(new Results("PLQ", "Palanga, Lithuania - Palanga"));
        AIRPORTS.add(new Results("PLS", "Providenciales, Turks And Caicos Islands"));
        AIRPORTS.add(new Results("PLU", "Belo Horizonte /Belo Horizon, Minas Gerais, Brazil - Confins/Pampulha"));
        AIRPORTS.add(new Results("PLW", "Palu, Indonesia - Mutiara"));
        AIRPORTS.add(new Results("PLZ", "Port Elizabeth, South Africa - Hf Verwoerd"));
        AIRPORTS.add(new Results("PMC", "Puerto Montt, Chile - Tepual"));
        AIRPORTS.add(new Results("PMD", "Palmdale, CA, USA - Air Force 42"));
        AIRPORTS.add(new Results("PMI", "Palma Mallorca, Mallorca Island, Spain - Palma Mallorca"));
        AIRPORTS.add(new Results("PMO", "Palermo, Sicily, Italy - Punta Raisi"));
        AIRPORTS.add(new Results("PMR", "Palmerston North, New Zealand - Palmerstown North"));
        AIRPORTS.add(new Results("PMV", "Porlamar, Venezuela - Gral Santiago Marino"));
        AIRPORTS.add(new Results("PNA", "Pamplona, Spain - Pamplona - Noain"));
        AIRPORTS.add(new Results("PNC", "Ponca City, OK, USA"));
        AIRPORTS.add(new Results("PNH", "Phnom Penh, Cambodia - Pochentong"));
        AIRPORTS.add(new Results("PNI", "Pohnpei, Caroline Islands, Micronesia - Pohnpei International"));
        AIRPORTS.add(new Results("PNK", "Pontianak, Indonesia - Supadio"));
        AIRPORTS.add(new Results("PNL", "Pantelleria, Italy - Pantelleria"));
        AIRPORTS.add(new Results("PNQ", "Poona, India - Lohegaon Poona"));
        AIRPORTS.add(new Results("PNR", "Pointe Noire, Congo - Pointe Noire"));
        AIRPORTS.add(new Results("PNS", "Pensacola, FL, USA"));
        AIRPORTS.add(new Results("POA", "Porto Alegre, Rio Grande Do Sul, Brazil - Salgado Filho"));
        AIRPORTS.add(new Results("POG", "Port Gentil, Gabon - Port Gentil"));
        AIRPORTS.add(new Results("POM", "Port Moresby, Papua New Guinea - Jackson"));
        AIRPORTS.add(new Results("POP", "Puerto Plata, Dominican Republic - La Union"));
        AIRPORTS.add(new Results("POR", "Pori, Finland - Pori"));
        AIRPORTS.add(new Results("POS", "Port Of Spain, Trinidad, Trinidad And Tobago - Piarco International Airport"));
        AIRPORTS.add(new Results("POU", "Poughkeepsie, NY, USA - Dutchess County"));
        AIRPORTS.add(new Results("POZ", "Poznan, Poland - Lawica"));
        AIRPORTS.add(new Results("PPG", "Pago Pago, American Samoa - International"));
        AIRPORTS.add(new Results("PPS", "Puerto Princesa, Philippines - Puerto Princesa"));
        AIRPORTS.add(new Results("PPT", "Papeete, French Polynesia - Intl Tahiti-Faaa"));
        AIRPORTS.add(new Results("PQI", "Presque Isle, ME, USA"));
        AIRPORTS.add(new Results("PQQ", "Port Macquarie, New South Wales, Australia - Port Macquarie"));
        AIRPORTS.add(new Results("PRC", "Prescott, AZ, USA"));
        AIRPORTS.add(new Results("PRG", "Prague, Czech Republic - Ruzyne"));
        AIRPORTS.add(new Results("PRI", "Praslin Island, Seychelles"));
        AIRPORTS.add(new Results("PSA", "Pisa, Italy - G Galilei"));
        AIRPORTS.add(new Results("PSC", "Pasco, WA, USA"));
        AIRPORTS.add(new Results("PSE", "Ponce, PR, USA - Mercedita"));
        AIRPORTS.add(new Results("PSG", "Petersburg, AK, USA - Municipal"));
        AIRPORTS.add(new Results("PSM", "Portsmouth, NH, USA - Pease Intl Tradeport"));
        AIRPORTS.add(new Results("PSO", "Pasto, Colombia - Cano"));
        AIRPORTS.add(new Results("PSP", "Palm Springs, CA, USA - Palm Springs Municipal"));
        AIRPORTS.add(new Results("PSR", "Pescara, Italy - Liberi"));
        AIRPORTS.add(new Results("PSZ", "Puerto Suarez, Bolivia"));
        AIRPORTS.add(new Results("PTF", "Malololailai, Fiji - Malololailai"));
        AIRPORTS.add(new Results("PTG", "Pietersburg, South Africa"));
        AIRPORTS.add(new Results("PTP", "Pointe A Pitre, Guadeloupe - Le Raizet"));
        AIRPORTS.add(new Results("PTY", "Panama City, Panama - Tocumen International Airport"));
        AIRPORTS.add(new Results("PUB", "Pueblo, CO, USA - Pueblo Memorial Airport"));
        AIRPORTS.add(new Results("PUJ", "Punta Cana, Dominican Republic"));
        AIRPORTS.add(new Results("PUQ", "Punta Arenas, Chile - Presidente Ibanez"));
        AIRPORTS.add(new Results("PUS", "Pusan, South Korea - Kimhae"));
        AIRPORTS.add(new Results("PUW", "Pullman, WA, USA - Pullman"));
        AIRPORTS.add(new Results("PUY", "Pula, Croatia (Hrvatska) - Pula"));
        AIRPORTS.add(new Results("PUZ", "Puerto Cabezas, Nicaragua - Puerto Cabezas"));
        AIRPORTS.add(new Results("PVC", "Provincetown, MA, USA - Provincetown Municipal Airport"));
        AIRPORTS.add(new Results("PVD", "Providence, RI, USA - Tf Green State Airport"));
        AIRPORTS.add(new Results("PVR", "Puerto Vallarta, Jalisco, Mexico - Gustavo Diaz Ordaz"));
        AIRPORTS.add(new Results("PVU", "Provo, UT, USA - Provo"));
        AIRPORTS.add(new Results("PWK", "Chicago, IL, USA - Pal-Waukee Airport"));
        AIRPORTS.add(new Results("PWM", "Portland, ME, USA - Portland International Jetport"));
        AIRPORTS.add(new Results("PWT", "Bremerton, WA, USA - Municipal"));
        AIRPORTS.add(new Results("PXM", "Puerto Escondido, Oaxaca, Mexico"));
        AIRPORTS.add(new Results("PXO", "Porto Santo, Madeira Islands, Portugal - Porto Santo"));
        AIRPORTS.add(new Results("PZE", "Penzance, England, United Kingdom - Penzance"));
        AIRPORTS.add(new Results("PZO", "Puerto Ordaz, Venezuela - Puerto Ordaz"));
        AIRPORTS.add(new Results("QBF", "Vail/Eagle, CO, USA"));
        AIRPORTS.add(new Results("QDU", "Duesseldorf, Germany - Main Train Station"));
        AIRPORTS.add(new Results("QKB", "Breckenridge, CO, USA"));
        AIRPORTS.add(new Results("QKL", "Cologne, Germany - Train Main Railroad Station"));
        AIRPORTS.add(new Results("QRO", "Queretaro, Queretaro, Mexico"));
        AIRPORTS.add(new Results("QSY", "Sydney, New South Wales, Australia"));
        AIRPORTS.add(new Results("RAB", "Rabaul, Papua New Guinea - Lakunai"));
        AIRPORTS.add(new Results("RAJ", "Rajkot, India - Rajkot"));
        AIRPORTS.add(new Results("RAK", "Marrakech, Morocco - Menara"));
        AIRPORTS.add(new Results("RAP", "Rapid City, SD, USA - Rapid City Regional Airport"));
        AIRPORTS.add(new Results("RAR", "Rarotonga, Cook Islands - Rarotonga"));
        AIRPORTS.add(new Results("RBA", "Rabat, Morocco - Sale"));
        AIRPORTS.add(new Results("RCB", "Richards Bay, South Africa - Richards Bay"));
        AIRPORTS.add(new Results("RCE", "Roche Harbor, WA, USA - Roche Harbor"));
        AIRPORTS.add(new Results("RDD", "Redding, CA, USA - Redding Municipal Airport"));
        AIRPORTS.add(new Results("RDG", "Reading, PA, USA - Municipal / Spaatz Field"));
        AIRPORTS.add(new Results("RDU", "Raleigh/Durham, NC, USA - Raleigh Durham International Arpt"));
        AIRPORTS.add(new Results("REC", "Recife, Pernambuco, Brazil - Guararapes International"));
        AIRPORTS.add(new Results("REG", "Reggio Calabria, Italy - Tito Menniti"));
        AIRPORTS.add(new Results("REL", "Trelew, Chubut, Argentina"));
        AIRPORTS.add(new Results("RES", "Resistencia, Chaco, Argentina"));
        AIRPORTS.add(new Results("REU", "Reus, Spain - Reus"));
        AIRPORTS.add(new Results("REX", "Reynosa, Tamaulipas, Mexico - General Lucio Blanco Airport"));
        AIRPORTS.add(new Results("RFD", "Rockford, IL, USA - Greater Rockford"));
        AIRPORTS.add(new Results("RGA", "Rio Grande, Tierra Del Fuego, Argentina"));
        AIRPORTS.add(new Results("RGL", "Rio Gallegos, Santa Cruz, Argentina - Rio Gallegos-Internacional"));
        AIRPORTS.add(new Results("RGN", "Yangon, Myanmar - Mingaladon"));
        AIRPORTS.add(new Results("RHI", "Rhinelander, WI, USA - Rhinelander Oneida County Airport"));
        AIRPORTS.add(new Results("RHO", "Rhodes, Greece - Paradisi"));
        AIRPORTS.add(new Results("RIC", "Richmond, VA, USA - Richmond International Airport"));
        AIRPORTS.add(new Results("RIO", "Rio De Janeiro, Rio De Janeiro, Brazil"));
        AIRPORTS.add(new Results("RIW", "Riverton, WY, USA - Riverton Regional Airport"));
        AIRPORTS.add(new Results("RIX", "Riga, Latvia - Riga"));
        AIRPORTS.add(new Results("RKD", "Rockland, ME, USA - Rockland"));
        AIRPORTS.add(new Results("RKS", "Rock Springs, WY, USA - Rock Springs Sweetwater Cty Arpt"));
        AIRPORTS.add(new Results("RKV", "Reykjavik, Iceland - Reykjavik Domestic Airport"));
        AIRPORTS.add(new Results("RMA", "Roma, Queensland, Australia - Roma"));
        AIRPORTS.add(new Results("RNB", "Ronneby, Sweden - Kallinge"));
        AIRPORTS.add(new Results("RNN", "Bornholm, Denmark - Arnager"));
        AIRPORTS.add(new Results("RNO", "Reno, NV, USA - Reno-Cannon International Apt"));
        AIRPORTS.add(new Results("RNS", "Rennes, France - St Jacques"));
        AIRPORTS.add(new Results("ROA", "Roanoke, VA, USA - Roanoke Regional Airport"));
        AIRPORTS.add(new Results("ROC", "Rochester, NY, USA - Monroe County Airport"));
        AIRPORTS.add(new Results("ROM", "Rome, Italy - Leonardo Da Vinci / Fiumicino"));
        AIRPORTS.add(new Results("ROP", "Rota, Northern Mariana Islands - Rota"));
        AIRPORTS.add(new Results("ROR", "Koror, Palau - Airai"));
        AIRPORTS.add(new Results("ROS", "Rosario, Santa Fe, Argentina - Fisherton"));
        AIRPORTS.add(new Results("ROV", "Rostov, Russia - Rostov"));
        AIRPORTS.add(new Results("ROW", "Roswell, NM, USA - Industrial Air Center"));
        AIRPORTS.add(new Results("RPR", "Raipur, India"));
        AIRPORTS.add(new Results("RRG", "Rodrigues Island, Mauritius - Rodrigues"));
        AIRPORTS.add(new Results("RSA", "Santa Rosa, La Pampa, Argentina"));
        AIRPORTS.add(new Results("RSD", "Rock Sound, Bahamas"));
        AIRPORTS.add(new Results("RST", "Rochester, MN, USA - Rochester Municipal"));
        AIRPORTS.add(new Results("RSU", "Yosu, South Korea - Yosu Airport"));
        AIRPORTS.add(new Results("RSW", "Fort Myers, FL, USA - Regional Southwest Airport"));
        AIRPORTS.add(new Results("RTB", "Roatan, Honduras - Roatan"));
        AIRPORTS.add(new Results("RTM", "Rotterdam, Netherlands - Rotterdam"));
        AIRPORTS.add(new Results("RUH", "Riyadh, Saudi Arabia - King Khaled Intl"));
        AIRPORTS.add(new Results("RUI", "Ruidoso, NM, USA"));
        AIRPORTS.add(new Results("RUN", "St-Denis De La Reunion, Reunion - Gillot"));
        AIRPORTS.add(new Results("RUT", "Rutland, VT, USA"));
        AIRPORTS.add(new Results("RWI", "Rocky Mount, NC, USA - Wilson"));
        AIRPORTS.add(new Results("SAB", "Saba Island, Netherlands Antilles"));
        AIRPORTS.add(new Results("SAF", "Santa Fe, NM, USA - Santa Fe Municipal Airport"));
        AIRPORTS.add(new Results("SAH", "Sanaa, Yemen - International"));
        AIRPORTS.add(new Results("SAL", "San Salvador, El Salvador - El Salvadore Intl Airport"));
        AIRPORTS.add(new Results("SAN", "San Diego, CA, USA - Lindbergh International Airport"));
        AIRPORTS.add(new Results("SAP", "San Pedro Sula, Honduras - La Mesa"));
        AIRPORTS.add(new Results("SAT", "San Antonio, TX, USA - San Antonio International"));
        AIRPORTS.add(new Results("SAV", "Savannah, GA, USA - Travis Field"));
        AIRPORTS.add(new Results("SBA", "Santa Barbara, CA, USA - Santa Barbara Airport"));
        AIRPORTS.add(new Results("SBH", "St Barthelemy, Guadeloupe"));
        AIRPORTS.add(new Results("SBN", "South Bend, IN, USA - Michiana Regional Airport"));
        AIRPORTS.add(new Results("SBP", "San Luis Obispo, CA, USA - San Luis Obispo County Airport"));
        AIRPORTS.add(new Results("SBW", "Sibu, Sarawak, Malaysia - Sibu"));
        AIRPORTS.add(new Results("SBY", "Salisbury, MD, USA - Salisbury-Wicomico County Arpt"));
        AIRPORTS.add(new Results("SCE", "State College, PA, USA - University Park Arpt"));
        AIRPORTS.add(new Results("SCL", "Santiago, Chile - Aeropuerto Comodoro Arturo Merino Benitez"));
        AIRPORTS.add(new Results("SCN", "Saarbruecken, Germany - Ensheim"));
        AIRPORTS.add(new Results("SCQ", "Santiago De Compostela, Spain - Santiago"));
        AIRPORTS.add(new Results("SCU", "Santiago, Cuba - Santiago-Antonio Maceo Cuba"));
        AIRPORTS.add(new Results("SDF", "Louisville, KY, USA - Standiford Field"));
        AIRPORTS.add(new Results("SDJ", "Sendai, Japan - Sendai"));
        AIRPORTS.add(new Results("SDK", "Sandakan, Sabah, Malaysia"));
        AIRPORTS.add(new Results("SDL", "Sundsvall, Sweden - Sundsvall"));
        AIRPORTS.add(new Results("SDN", "Sandane, Norway"));
        AIRPORTS.add(new Results("SDQ", "Santo Domingo, Dominican Republic - Las Americas"));
        AIRPORTS.add(new Results("SDR", "Santander, Spain - Santander"));
        AIRPORTS.add(new Results("SDU", "Rio De Janeiro, Rio De Janeiro, Brazil - Santos Dumont"));
        AIRPORTS.add(new Results("SDX", "Sedona, AZ, USA"));
        AIRPORTS.add(new Results("SDY", "Sidney, MT, USA"));
        AIRPORTS.add(new Results("SEA", "Seattle, WA, USA - Seattle Tacoma Intl Airport"));
        AIRPORTS.add(new Results("SEL", "Seoul, South Korea - Kimpo International"));
        AIRPORTS.add(new Results("SEZ", "Mahe Island, Seychelles - Mahe Island Seychelles Intl"));
        AIRPORTS.add(new Results("SFA", "Sfax, Tunisia - Sfax Airport"));
        AIRPORTS.add(new Results("SFG", "St Martin, Netherlands Antilles - Esperance"));
        AIRPORTS.add(new Results("SFJ", "Kangerlussuaq, Greenland - Sondre Stromfjord"));
        AIRPORTS.add(new Results("SFN", "Santa Fe, Santa Fe, Argentina"));
        AIRPORTS.add(new Results("SFO", "San Francisco, CA, USA - San Francisco Intl Airport"));
        AIRPORTS.add(new Results("SFT", "Skelleftea, Sweden - Skelleftea"));
        AIRPORTS.add(new Results("SGC", "Surgut, Russia"));
        AIRPORTS.add(new Results("SGD", "Sonderborg, Denmark - Sonderborg"));
        AIRPORTS.add(new Results("SGF", "Springfield, MO, USA - Springfield Regional Airport"));
        AIRPORTS.add(new Results("SGN", "Ho Chi Minh City, Vietnam - Tan Son Nhut"));
        AIRPORTS.add(new Results("SGO", "St George, Queensland, Australia - St George"));
        AIRPORTS.add(new Results("SGU", "Saint George, UT, USA - St George"));
        AIRPORTS.add(new Results("SGY", "Skagway, AK, USA"));
        AIRPORTS.add(new Results("SHA", "Shanghai, China - Shanghai Intl /Hongqiao/"));
        AIRPORTS.add(new Results("SHC", "Indaselassie, Ethiopia"));
        AIRPORTS.add(new Results("SHD", "Staunton, VA, USA - Shenandoah Valley Regional"));
        AIRPORTS.add(new Results("SHE", "Shenyang, China - Shenyang"));
        AIRPORTS.add(new Results("SHJ", "Sharjah, United Arab Emirates - Sharjah"));
        AIRPORTS.add(new Results("SHO", "Sokcho, South Korea"));
        AIRPORTS.add(new Results("SHR", "Sheridan, WY, USA - Sheridan County Airport"));
        AIRPORTS.add(new Results("SHV", "Shreveport, LA, USA - Regional Airport"));
        AIRPORTS.add(new Results("SID", "Sal, Cape Verde - Amilcar Cabral International"));
        AIRPORTS.add(new Results("SIN", "Singapore, Singapore - Changi International Airport"));
        AIRPORTS.add(new Results("SIP", "Simferopol, Ukraine - Simferopol"));
        AIRPORTS.add(new Results("SIT", "Sitka, AK, USA - Sitka"));
        AIRPORTS.add(new Results("SJC", "San Jose, CA, USA - San Jose International Airport"));
        AIRPORTS.add(new Results("SJD", "San Jose Del Cabo, Baja California Sur, Mexico - Los Cabos Intl Airport"));
        AIRPORTS.add(new Results("SJI", "San Jose, Philippines - Mcguire Field"));
        AIRPORTS.add(new Results("SJJ", "Sarajevo, Bosnia And Herzegowina - Butmir"));
        AIRPORTS.add(new Results("SJO", "San Jose, Costa Rica - Juan Santamaria International"));
        AIRPORTS.add(new Results("SJT", "San Angelo, TX, USA"));
        AIRPORTS.add(new Results("SJU", "San Juan, PR, USA - Luis Munoz Marin International"));
        AIRPORTS.add(new Results("SJW", "Shijiazhuang, China - Shijiazhuang"));
        AIRPORTS.add(new Results("SKB", "St Kitts, Saint Kitts And Nevis - Golden Rock"));
        AIRPORTS.add(new Results("SKD", "Samarkand, Uzbekistan"));
        AIRPORTS.add(new Results("SKG", "Thessaloniki, Greece - Thessaloniki"));
        AIRPORTS.add(new Results("SKP", "Skopje, Macedonia - Skopje"));
        AIRPORTS.add(new Results("SKS", "Vojens Lufthavn, Denmark - Jojens"));
        AIRPORTS.add(new Results("SLA", "Salta, Salta, Argentina - International"));
        AIRPORTS.add(new Results("SLC", "Salt Lake City, UT, USA - Salt Lake City International Arpt"));
        AIRPORTS.add(new Results("SLK", "Saranac Lake, NY, USA - Adirondack"));
        AIRPORTS.add(new Results("SLN", "Salina, KS, USA - Salina Municipal"));
        AIRPORTS.add(new Results("SLP", "San Luis Potosi, San Luis Potosi, Mexico"));
        AIRPORTS.add(new Results("SLU", "St Lucia, Saint Lucia - Vigie Field"));
        AIRPORTS.add(new Results("SLW", "Saltillo, Coahuila, Mexico - Saltillo"));
        AIRPORTS.add(new Results("SLZ", "Sao Luiz, Maranhao, Brazil - Tirirical"));
        AIRPORTS.add(new Results("SMF", "Sacramento, CA, USA - Sacramento Metropolitan"));
        AIRPORTS.add(new Results("SML", "Stella Maris, Bahamas"));
        AIRPORTS.add(new Results("SMM", "Semporna, Sabah, Malaysia - Semporna"));
        AIRPORTS.add(new Results("SMS", "St Marie, Madagascar"));
        AIRPORTS.add(new Results("SMX", "Santa Maria, CA, USA - Santa Maria Public Airport"));
        AIRPORTS.add(new Results("SNA", "Santa Ana, CA, USA - John Wayne Airport"));
        AIRPORTS.add(new Results("SNB", "Snake Bay, Northern Territory, Australia"));
        AIRPORTS.add(new Results("SNN", "Shannon, Ireland - Shannon"));
        AIRPORTS.add(new Results("SNO", "Sakon Nakhon, Thailand"));
        AIRPORTS.add(new Results("SOF", "Sofia, Bulgaria - Sofia Intl"));
        AIRPORTS.add(new Results("SOG", "Sogndal, Norway - Haukasen"));
        AIRPORTS.add(new Results("SOM", "San Tome, Venezuela"));
        AIRPORTS.add(new Results("SOP", "Southern Pines, NC, USA - Pinehurst"));
        AIRPORTS.add(new Results("SOU", "Southampton, England, United Kingdom - Eastleigh"));
        AIRPORTS.add(new Results("SOW", "Show Low, AZ, USA"));
        AIRPORTS.add(new Results("SPB", "St Thomas Island, VI, USA - Seaplane Base"));
        AIRPORTS.add(new Results("SPC", "Santa Cruz La Palma, Canary Islands, Spain - La Palma"));
        AIRPORTS.add(new Results("SPD", "Saidpur, Bangladesh"));
        AIRPORTS.add(new Results("SPI", "Springfield, IL, USA - Capital Airport"));
        AIRPORTS.add(new Results("SPN", "Saipan, Northern Mariana Islands - Saipan Intl Northrn Mariana Isles"));
        AIRPORTS.add(new Results("SPR", "San Pedro, Belize - San Pedro"));
        AIRPORTS.add(new Results("SPS", "Wichita Falls, TX, USA - Wichita Falls Municipal"));
        AIRPORTS.add(new Results("SPU", "Split, Croatia (Hrvatska) - Split"));
        AIRPORTS.add(new Results("SPW", "Spencer, IA, USA - Spencer Municipal Airport"));
        AIRPORTS.add(new Results("SRE", "Sucre, Bolivia - Sucre"));
        AIRPORTS.add(new Results("SRQ", "Sarasota/Bradenton, FL, USA - Sarasota-Bradenton"));
        AIRPORTS.add(new Results("SSA", "Salvador, Bahia, Brazil - Dois De Julho"));
        AIRPORTS.add(new Results("SSB", "St Croix Island, VI, USA - Sea Plane Base"));
        AIRPORTS.add(new Results("SSG", "Malabo, Equatorial Guinea - Santa Isabel"));
        AIRPORTS.add(new Results("SSH", "Sharm El Sheikh, Egypt - Ophira"));
        AIRPORTS.add(new Results("SSJ", "Sandnessjoen, Norway - Stokka"));
        AIRPORTS.add(new Results("SSQ", "La Sarre, Quebec, Canada"));
        AIRPORTS.add(new Results("STC", "Saint Cloud, MN, USA - Saint Cloud"));
        AIRPORTS.add(new Results("STD", "Santo Domingo, Venezuela - Mayor Humberto Vivas Guerrero"));
        AIRPORTS.add(new Results("STI", "Santiago, Dominican Republic - Municipal"));
        AIRPORTS.add(new Results("STL", "St Louis, MO, USA - Lambert-St Louis Internatl"));
        AIRPORTS.add(new Results("STM", "Santarem, Para, Brazil"));
        AIRPORTS.add(new Results("STN", "London, England, United Kingdom - Stansted"));
        AIRPORTS.add(new Results("STP", "St Paul, MN, USA - Downtown Airport"));
        AIRPORTS.add(new Results("STR", "Stuttgart, Germany - Echterdingen"));
        AIRPORTS.add(new Results("STS", "Santa Rosa, CA, USA - Sonoma County Airport"));
        AIRPORTS.add(new Results("STT", "St Thomas Island, VI, USA - Cyril E King Arpt"));
        AIRPORTS.add(new Results("STX", "St Croix Island, VI, USA"));
        AIRPORTS.add(new Results("SUB", "Surabaya, Indonesia - Juanda Airport"));
        AIRPORTS.add(new Results("SUE", "Sturgeon Bay, WI, USA"));
        AIRPORTS.add(new Results("SUN", "Sun Valley/Hailey, ID, USA"));
        AIRPORTS.add(new Results("SUV", "Suva, Fiji - Nausori"));
        AIRPORTS.add(new Results("SVD", "St Vincent, St. Vincent And The Grenadines"));
        AIRPORTS.add(new Results("SVG", "Stavanger, Norway - Sola"));
        AIRPORTS.add(new Results("SVL", "Savonlinna, Finland - Savonlinna"));
        AIRPORTS.add(new Results("SVO", "Moscow, Russia - Sheremetyevo"));
        AIRPORTS.add(new Results("SVQ", "Sevilla, Spain"));
        AIRPORTS.add(new Results("SVU", "Savusavu, Fiji - Savusavu"));
        AIRPORTS.add(new Results("SVX", "Ekaterinburg, Russia"));
        AIRPORTS.add(new Results("SVZ", "San Antonio, Venezuela"));
        AIRPORTS.add(new Results("SWA", "Shantou, China"));
        AIRPORTS.add(new Results("SWF", "Newburgh/Poughkeepsie, NY, USA - Stewart"));
        AIRPORTS.add(new Results("SWP", "Swakopmund, Namibia"));
        AIRPORTS.add(new Results("SWQ", "Sumbawa Island, Indonesia - Brang Bidji"));
        AIRPORTS.add(new Results("SXB", "Strasbourg, France - Entzheim"));
        AIRPORTS.add(new Results("SXF", "Berlin, Germany - Schoenefeld"));
        AIRPORTS.add(new Results("SXL", "Sligo, Ireland - Collooney"));
        AIRPORTS.add(new Results("SXM", "St Maarten, Netherlands Antilles - Juliana"));
        AIRPORTS.add(new Results("SXR", "Srinagar, India"));
        AIRPORTS.add(new Results("SYD", "Sydney, New South Wales, Australia - Sydney /Kingsford-Smith/ Airport"));
        AIRPORTS.add(new Results("SYO", "Shonai, Japan - Shonai"));
        AIRPORTS.add(new Results("SYR", "Syracuse, NY, USA - Hancock International"));
        AIRPORTS.add(new Results("SYX", "Sanya, China"));
        AIRPORTS.add(new Results("SYY", "Stornoway, Scotland, United Kingdom - Stornoway"));
        AIRPORTS.add(new Results("SYZ", "Shiraz, Iran - Shiraz"));
        AIRPORTS.add(new Results("SZG", "Salzburg, Austria - Salzburg"));
        AIRPORTS.add(new Results("SZX", "Shenzhen, China - Shenzhen"));
        AIRPORTS.add(new Results("SZZ", "Szczecin, Poland - Goleniow"));
        AIRPORTS.add(new Results("TAB", "Tobago, Tobago, Trinidad And Tobago - Crown Point"));
        AIRPORTS.add(new Results("TAC", "Tacloban, Philippines - Dz Romualdez"));
        AIRPORTS.add(new Results("TAE", "Taegu, South Korea"));
        AIRPORTS.add(new Results("TAG", "Tagbilaran, Philippines - Tagbilaran"));
        AIRPORTS.add(new Results("TAI", "Taiz, Yemen - Al-Janad"));
        AIRPORTS.add(new Results("TAM", "Tampico, Tamaulipas, Mexico"));
        AIRPORTS.add(new Results("TAP", "Tapachula, Chiapas, Mexico - Tapachula International"));
        AIRPORTS.add(new Results("TAS", "Tashkent, Uzbekistan - Tashkent"));
        AIRPORTS.add(new Results("TAT", "Tatry/Poprad, Slovakia - Tatry/Poprad"));
        AIRPORTS.add(new Results("TBN", "Ft Leonard Wood, MO, USA - Forney Field"));
        AIRPORTS.add(new Results("TBP", "Tumbes, Peru - Tumbes"));
        AIRPORTS.add(new Results("TBS", "Tbilisi, Georgia - Novo Alexeyevka"));
        AIRPORTS.add(new Results("TBT", "Tabatinga, Amazonas, Brazil"));
        AIRPORTS.add(new Results("TBU", "Nuku Alofa/Tongatapu, Tonga - International"));
        AIRPORTS.add(new Results("TCI", "Tenerife, Canary Islands, Spain - Tenerife Norte Los Rodeos"));
        AIRPORTS.add(new Results("TCL", "Tuscaloosa, AL, USA - Van De Graff"));
        AIRPORTS.add(new Results("TDD", "Trinidad, Bolivia"));
        AIRPORTS.add(new Results("TED", "Thisted, Denmark"));
        AIRPORTS.add(new Results("TER", "Terceira Island, Azores Islands, Portugal - Lajes"));
        AIRPORTS.add(new Results("TEX", "Telluride, CO, USA - Telluride Municipal Airport"));
        AIRPORTS.add(new Results("TEZ", "Tezpur, India - Salonbari"));
        AIRPORTS.add(new Results("TFN", "Tenerife, Canary Islands, Spain - Tenerife Norte Los Rodeos"));
        AIRPORTS.add(new Results("TFS", "Tenerife, Canary Islands, Spain - Reina Sofia"));
        AIRPORTS.add(new Results("TGD", "Podgorica, Yugoslavia - Golubovci"));
        AIRPORTS.add(new Results("TGG", "Kuala Terengganu, Malaysia - Sultan Mahmood"));
        AIRPORTS.add(new Results("TGM", "Tirgu Mures, Romania - Tirgu Mures"));
        AIRPORTS.add(new Results("TGU", "Tegucigalpa, Honduras - Toncontin"));
        AIRPORTS.add(new Results("TGZ", "Tuxtla Gutierrez, Chiapas, Mexico - Llano San Juan"));
        AIRPORTS.add(new Results("THE", "Teresina, Piaui, Brazil - Teresina"));
        AIRPORTS.add(new Results("THF", "Berlin, Germany - Tempelhof"));
        AIRPORTS.add(new Results("THR", "Tehran, Iran - Mehrabad"));
        AIRPORTS.add(new Results("THU", "Pituffik, Greenland - Thule Airport"));
        AIRPORTS.add(new Results("TIA", "Tirana, Albania - Rinas"));
        AIRPORTS.add(new Results("TIJ", "Tijuana, Baja California, Mexico - General Abelardo L Rodriguez"));
        AIRPORTS.add(new Results("TIQ", "Tinian, Northern Mariana Islands - Tinian"));
        AIRPORTS.add(new Results("TIS", "Thursday Island, Queensland, Australia - Horn Island"));
        AIRPORTS.add(new Results("TIV", "Tivat, Yugoslavia - Tivat"));
        AIRPORTS.add(new Results("TIZ", "Tari, Papua New Guinea"));
        AIRPORTS.add(new Results("TJA", "Tarija, Bolivia"));
        AIRPORTS.add(new Results("TJM", "Tyumen, Russia - Tyumen"));
        AIRPORTS.add(new Results("TKK", "Truk, Caroline Islands, Micronesia - Truk"));
        AIRPORTS.add(new Results("TKQ", "Kigoma, Tanzania"));
        AIRPORTS.add(new Results("TKS", "Tokushima, Japan - Tokushima"));
        AIRPORTS.add(new Results("TKU", "Turku, Finland - Turku"));
        AIRPORTS.add(new Results("TLH", "Tallahassee, FL, USA"));
        AIRPORTS.add(new Results("TLL", "Tallinn, Estonia - Ulemiste"));
        AIRPORTS.add(new Results("TLS", "Toulouse, France - Blagnac"));
        AIRPORTS.add(new Results("TLV", "Tel Aviv Yafo, Israel - Ben-Gurion International"));
        AIRPORTS.add(new Results("TMP", "Tampere, Finland - Tampere-Pirkkala"));
        AIRPORTS.add(new Results("TMW", "Tamworth, New South Wales, Australia - Tamworth"));
        AIRPORTS.add(new Results("TNG", "Tangier, Morocco - Boukhalef Souahel"));
        AIRPORTS.add(new Results("TNR", "Antananarivo, Madagascar - Ivato"));
        AIRPORTS.add(new Results("TOL", "Toledo, OH, USA - Toledo Express Airport"));
        AIRPORTS.add(new Results("TOS", "Tromso, Norway - Tromso/Langes"));
        AIRPORTS.add(new Results("TOY", "Toyama, Japan - Toyama"));
        AIRPORTS.add(new Results("TPA", "Tampa, FL, USA - Tampa International"));
        AIRPORTS.add(new Results("TPE", "Taipei, Taiwan - Chiang Kai Shek Airport"));
        AIRPORTS.add(new Results("TPL", "Temple, TX, USA"));
        AIRPORTS.add(new Results("TPP", "Tarapoto, Peru - Tarapoto"));
        AIRPORTS.add(new Results("TPQ", "Tepic, Nayarit, Mexico"));
        AIRPORTS.add(new Results("TPS", "Trapani, Sicily, Italy - Birgi"));
        AIRPORTS.add(new Results("TRC", "Torreon, Coahuila, Mexico"));
        AIRPORTS.add(new Results("TRD", "Trondheim, Norway - Trondheim-Vaernes"));
        AIRPORTS.add(new Results("TRE", "Tiree, Scotland, United Kingdom - Tiree Island"));
        AIRPORTS.add(new Results("TRF", "Sandefjord, Norway - Torf"));
        AIRPORTS.add(new Results("TRG", "Tauranga, New Zealand - Tauranga"));
        AIRPORTS.add(new Results("TRI", "Bristol/Johnson City/Kingsport, TN, USA - Municipal Tri-City Airport"));
        AIRPORTS.add(new Results("TRK", "Tarakan, Indonesia - Tarakan"));
        AIRPORTS.add(new Results("TRN", "Turin, Italy - Caselle"));
        AIRPORTS.add(new Results("TRS", "Trieste, Italy - Ronchi Dei Legionari"));
        AIRPORTS.add(new Results("TRU", "Trujillo, Peru - Trujillo"));
        AIRPORTS.add(new Results("TRV", "Trivandrum, India - Trivandrum"));
        AIRPORTS.add(new Results("TRZ", "Tiruchirapally, India - Civil"));
        AIRPORTS.add(new Results("TSA", "Taipei, Taiwan - Sung Shan"));
        AIRPORTS.add(new Results("TSR", "Timisoara, Romania - Timisoara"));
        AIRPORTS.add(new Results("TSS", "New York, NY, USA - East 34Th Street Heliport"));
        AIRPORTS.add(new Results("TSV", "Townsville, Queensland, Australia - Townsville"));
        AIRPORTS.add(new Results("TTE", "Ternate, Indonesia - Babullah"));
        AIRPORTS.add(new Results("TTJ", "Tottori, Japan - Tottori"));
        AIRPORTS.add(new Results("TTN", "Trenton, NJ, USA - Mercer County"));
        AIRPORTS.add(new Results("TUC", "Tucuman, Tucuman, Argentina - Benjamin Matienzo"));
        AIRPORTS.add(new Results("TUF", "Tours, France - St Symphorien"));
        AIRPORTS.add(new Results("TUL", "Tulsa, OK, USA - Tulsa International"));
        AIRPORTS.add(new Results("TUN", "Tunis, Tunisia - Carthage"));
        AIRPORTS.add(new Results("TUO", "Taupo, New Zealand - Taupo"));
        AIRPORTS.add(new Results("TUP", "Tupelo, MS, USA - Cd Lemons Municipal"));
        AIRPORTS.add(new Results("TUS", "Tucson, AZ, USA - Tucson International Airport"));
        AIRPORTS.add(new Results("TVC", "Traverse City, MI, USA - Cherry Capital Airport"));
        AIRPORTS.add(new Results("TVF", "Thief River Falls, MN, USA - Thief River Falls Municipal"));
        AIRPORTS.add(new Results("TVL", "South Lake Tahoe, CA, USA - Lake Tahoe"));
        AIRPORTS.add(new Results("TWB", "Toowoomba, Queensland, Australia - Toowoomba"));
        AIRPORTS.add(new Results("TWF", "Twin Falls, ID, USA"));
        AIRPORTS.add(new Results("TXK", "Texarkana, AR, USA - Municipal"));
        AIRPORTS.add(new Results("TXL", "Berlin, Germany - Tegel"));
        AIRPORTS.add(new Results("TXN", "Tunxi, China"));
        AIRPORTS.add(new Results("TYN", "Taiyuan, China"));
        AIRPORTS.add(new Results("TYR", "Tyler, TX, USA - Pounds Field"));
        AIRPORTS.add(new Results("TYS", "Knoxville, TN, USA - Mcghee Tyson"));
        AIRPORTS.add(new Results("TZA", "Belize City, Belize - Belize Municipal"));
        AIRPORTS.add(new Results("TZN", "South Andros, Bahamas - Congo Town"));
        AIRPORTS.add(new Results("TZX", "Trabzon, Turkey - Trabzon"));
        AIRPORTS.add(new Results("UAK", "Narsarsuaq, Greenland - Narssarssuaq"));
        AIRPORTS.add(new Results("UAQ", "San Juan, San Juan, Argentina"));
        AIRPORTS.add(new Results("UBJ", "Ube, Japan"));
        AIRPORTS.add(new Results("UCA", "Utica, NY, USA - Oneida County"));
        AIRPORTS.add(new Results("UDR", "Udaipur, India"));
        AIRPORTS.add(new Results("UEL", "Quelimane, Mozambique"));
        AIRPORTS.add(new Results("UET", "Quetta, Pakistan"));
        AIRPORTS.add(new Results("UGC", "Urgench, Uzbekistan"));
        AIRPORTS.add(new Results("UIB", "Quibdo, Colombia"));
        AIRPORTS.add(new Results("UIN", "Quincy, IL, USA - Baldwin Field"));
        AIRPORTS.add(new Results("UIO", "Quito, Ecuador - Mariscal"));
        AIRPORTS.add(new Results("UIP", "Quimper, France - Pluguffan"));
        AIRPORTS.add(new Results("ULN", "Ulan Bator, Mongolia - Ulan Bator"));
        AIRPORTS.add(new Results("ULY", "Ulyanovsk, Russia - Ulyanoysk"));
        AIRPORTS.add(new Results("UME", "Umea, Sweden - Umea"));
        AIRPORTS.add(new Results("UMR", "Woomera, South Australia, Australia - Woomera"));
        AIRPORTS.add(new Results("UNT", "Unst Shetland Islands, Scotland, United Kingdom"));
        AIRPORTS.add(new Results("UPG", "Ujung Pandang, Indonesia - Hasanudin"));
        AIRPORTS.add(new Results("UPN", "Uruapan, Michoacan, Mexico"));
        AIRPORTS.add(new Results("URC", "Urumqi, China"));
        AIRPORTS.add(new Results("URO", "Rouen, France - Rouen /Boos Airport"));
        AIRPORTS.add(new Results("URT", "Surat Thani, Thailand"));
        AIRPORTS.add(new Results("USH", "Ushuaia, Tierra Del Fuego, Argentina"));
        AIRPORTS.add(new Results("USM", "Koh Samui, Thailand"));
        AIRPORTS.add(new Results("USN", "Ulsan, South Korea"));
        AIRPORTS.add(new Results("UTH", "Udon Thani, Thailand - Udon"));
        AIRPORTS.add(new Results("UTN", "Upington, South Africa - Municipal"));
        AIRPORTS.add(new Results("UUD", "Ulan-Ude, Russia"));
        AIRPORTS.add(new Results("UVF", "St Lucia, Saint Lucia - Hewanorra"));
        AIRPORTS.add(new Results("VAA", "Vaasa, Finland - Vaasa"));
        AIRPORTS.add(new Results("VAR", "Varna, Bulgaria - Varna"));
        AIRPORTS.add(new Results("VAS", "Sivas, Turkey - Sivas"));
        AIRPORTS.add(new Results("VBY", "Visby, Sweden - Visby"));
        AIRPORTS.add(new Results("VCE", "Venice, Italy - Marco Polo"));
        AIRPORTS.add(new Results("VCT", "Victoria, TX, USA"));
        AIRPORTS.add(new Results("VDA", "Ovda, Israel"));
        AIRPORTS.add(new Results("VDS", "Vadso, Norway - Vadso"));
        AIRPORTS.add(new Results("VDZ", "Valdez, AK, USA"));
        AIRPORTS.add(new Results("VER", "Veracruz, Veracruz, Mexico - Las Bajadas / General Heriberto Jara"));
        AIRPORTS.add(new Results("VEY", "Vestmannaeyjar, Iceland - Vestmannaeyjar"));
        AIRPORTS.add(new Results("VFA", "Victoria Falls, Zimbabwe"));
        AIRPORTS.add(new Results("VGO", "Vigo, Spain"));
        AIRPORTS.add(new Results("VGT", "Las Vegas, NV, USA - North Air Terminal"));
        AIRPORTS.add(new Results("VIE", "Vienna, Austria - Schwechat"));
        AIRPORTS.add(new Results("VIJ", "Virgin Gorda, Virgin Islands (British)"));
        AIRPORTS.add(new Results("VIS", "Visalia, CA, USA - Visalia Municipal Airport"));
        AIRPORTS.add(new Results("VIT", "Vitoria, Spain - Vitoria"));
        AIRPORTS.add(new Results("VIX", "Vitoria, Espirito Santo, Brazil - Eureco Sales"));
        AIRPORTS.add(new Results("VKO", "Moscow, Russia - Vnukovo"));
        AIRPORTS.add(new Results("VLC", "Valencia, Spain - Valencia"));
        AIRPORTS.add(new Results("VLD", "Valdosta, GA, USA - Valdosta Regional"));
        AIRPORTS.add(new Results("VLG", "Villa Gesell, Buenos Aires, Argentina - Villa Gesell"));
        AIRPORTS.add(new Results("VLI", "Port Vila, Vanuatu - Bauerfield"));
        AIRPORTS.add(new Results("VLL", "Valladolid, Spain - Valladolid"));
        AIRPORTS.add(new Results("VLN", "Valencia, Venezuela - Valencia"));
        AIRPORTS.add(new Results("VNO", "Vilnius, Lithuania - Vilnius Airport"));
        AIRPORTS.add(new Results("VNS", "Varanasi, India - Babatpur"));
        AIRPORTS.add(new Results("VOG", "Volgograd, Russia - Volgograd"));
        AIRPORTS.add(new Results("VPS", "Valparaiso, FL, USA - Fort Walton Beach"));
        AIRPORTS.add(new Results("VRA", "Varadero, Cuba - Juan Gualberto Gomez"));
        AIRPORTS.add(new Results("VRB", "Vero Beach, FL, USA - Vero Beach Municipal"));
        AIRPORTS.add(new Results("VRK", "Varkaus, Finland - Varkaus"));
        AIRPORTS.add(new Results("VRN", "Verona, Italy - Verona"));
        AIRPORTS.add(new Results("VSA", "Villahermosa, Tabasco, Mexico - Carlos R Perez"));
        AIRPORTS.add(new Results("VSG", "Lugansk, Ukraine"));
        AIRPORTS.add(new Results("VST", "Vasteras, Sweden - Hasslo"));
        AIRPORTS.add(new Results("VTE", "Vientiane, Laos - Wattay"));
        AIRPORTS.add(new Results("VTZ", "Vishakhapatnam, India - Vishakhapatnam"));
        AIRPORTS.add(new Results("VUP", "Valledupar, Colombia"));
        AIRPORTS.add(new Results("VVI", "Santa Cruz, Bolivia - Viru Viru International"));
        AIRPORTS.add(new Results("VVO", "Vladivostok, Russia - Vladivostok Airport"));
        AIRPORTS.add(new Results("VXO", "Vaxjo, Sweden - Vaxjo"));
        AIRPORTS.add(new Results("WAT", "Waterford, Ireland"));
        AIRPORTS.add(new Results("WAW", "Warsaw, Poland - Okecie"));
        AIRPORTS.add(new Results("WBU", "Boulder, CO, USA"));
        AIRPORTS.add(new Results("WDG", "Enid, OK, USA - Woodring Municipal"));
        AIRPORTS.add(new Results("WDH", "Windhoek, Namibia - Jg Strijdom"));
        AIRPORTS.add(new Results("WGA", "Wagga-Wagga, New South Wales, Australia - Forest Hill"));
        AIRPORTS.add(new Results("WGE", "Walgett, New South Wales, Australia - Walgett"));
        AIRPORTS.add(new Results("WIC", "Wick, Scotland, United Kingdom - Wick"));
        AIRPORTS.add(new Results("WIL", "Nairobi, Kenya - Wilson Arpt"));
        AIRPORTS.add(new Results("WIN", "Winton, Queensland, Australia - Winton"));
        AIRPORTS.add(new Results("WLG", "Wellington, New Zealand - International"));
        AIRPORTS.add(new Results("WMH", "Mountain Home, AR, USA"));
        AIRPORTS.add(new Results("WNA", "Napakiak, AK, USA - Napakiak"));
        AIRPORTS.add(new Results("WRL", "Worland, WY, USA - Worland"));
        AIRPORTS.add(new Results("WRO", "Wroclaw, Poland - Strachowice"));
        AIRPORTS.add(new Results("XAW", "Capreol, Ontario, Canada - Capreol / Via Rail Service"));
        AIRPORTS.add(new Results("XAZ", "Cambellton, New Brunswick, Canada - Campbellton"));
        AIRPORTS.add(new Results("XBR", "Brockville, Ontario, Canada"));
        AIRPORTS.add(new Results("XCI", "Chambord, Quebec, Canada - Chambord / Via Rail Service"));
        AIRPORTS.add(new Results("XCM", "Chatham, Ontario, Canada"));
        AIRPORTS.add(new Results("XDL", "Chandler, Quebec, Canada - Chandler / Via Rail Service"));
        AIRPORTS.add(new Results("XDM", "Drummondville, Quebec, Canada"));
        AIRPORTS.add(new Results("XDU", "Hervey, Quebec, Canada - Hervey / Via Rail Service"));
        AIRPORTS.add(new Results("XEE", "Lac Edouard, Quebec, Canada - Lac Edouard / Via Rail Service"));
        AIRPORTS.add(new Results("XEH", "Ladysmith, British Columbia, Canada - Ladysmith / Via Rail Service"));
        AIRPORTS.add(new Results("XEJ", "Langford, British Columbia, Canada - Langford / Via Rail Service"));
        AIRPORTS.add(new Results("XEK", "Melville, Saskatchewan, Canada - Melville / Via Rail Service"));
        AIRPORTS.add(new Results("XEL", "New Carlisle, Quebec, Canada - New Carlisle / Via Rail Service"));
        AIRPORTS.add(new Results("XEM", "New Richmond, Quebec, Canada - New Richmond / Via Rail Service"));
        AIRPORTS.add(new Results("XEY", "Newcastle, New Brunswick, Canada - Newcastle / Via Rail Service"));
        AIRPORTS.add(new Results("XFD", "Stratford, Ontario, Canada"));
        AIRPORTS.add(new Results("XFE", "Parent, Quebec, Canada - Parent / Via Rail Service"));
        AIRPORTS.add(new Results("XFG", "Perce, Quebec, Canada - Perce / Via Rail Service"));
        AIRPORTS.add(new Results("XFL", "Shawinigan, Quebec, Canada - Shawinigan / Via Rail Service"));
        AIRPORTS.add(new Results("XFM", "Shawnigan, British Columbia, Canada - Shawnigan / Via Rail Service"));
        AIRPORTS.add(new Results("XFO", "Taschereau, Quebec, Canada - Taschereau / Via Rail Service"));
        AIRPORTS.add(new Results("XFQ", "Weymont, Quebec, Canada - Weymont / Via Rail Service"));
        AIRPORTS.add(new Results("XFS", "Alexandria, Ontario, Canada - Alexandria / Via Rail Service"));
        AIRPORTS.add(new Results("XFV", "Brantford, Ontario, Canada - Brantford / Via Rail Service"));
        AIRPORTS.add(new Results("XGJ", "Cobourg, Ontario, Canada - Cobourg / Via Rail Service"));
        AIRPORTS.add(new Results("XGK", "Coteau, Quebec, Canada - Coteau / Via Rail Service"));
        AIRPORTS.add(new Results("XGY", "Grimsby, Ontario, Canada - Grimsby / Via Rail Service"));
        AIRPORTS.add(new Results("XHM", "Georgetown, Ontario, Canada - Georgetown / Via Rail Service"));
        AIRPORTS.add(new Results("XHS", "Chemainus, British Columbia, Canada - Chemainus / Via Rail Service"));
        AIRPORTS.add(new Results("XIA", "Guelph, Ontario, Canada - Guelph / Via Rail Service"));
        AIRPORTS.add(new Results("XIB", "Ingersoll, Ontario, Canada - Ingersoll / Via Rail Service"));
        AIRPORTS.add(new Results("XID", "Maxville, Ontario, Canada - Maxville / Via Rail Service"));
        AIRPORTS.add(new Results("XIM", "Saint-Hyacinthe, Quebec, Canada - Saint Hyacinthe / Via Rail Service"));
        AIRPORTS.add(new Results("XIO", "St Marys, Ontario, Canada - St Marys / Via Rail Service"));
        AIRPORTS.add(new Results("XIP", "Woodstock, Ontario, Canada - Woodstock / Via Rail Service"));
        AIRPORTS.add(new Results("XIY", "Xi An, China - Xianyang"));
        AIRPORTS.add(new Results("XJL", "Joliette, Quebec, Canada - Joliette / Via Rail Service"));
        AIRPORTS.add(new Results("XJQ", "Jonquiere, Quebec, Canada - Jonquiere / Via Rail Service"));
        AIRPORTS.add(new Results("XLV", "Niagara Falls, Ontario, Canada"));
        AIRPORTS.add(new Results("XLZ", "Truro, Nova Scotia, Canada"));
        AIRPORTS.add(new Results("XMN", "Xiamen, China - Xiamen International"));
        AIRPORTS.add(new Results("XOK", "Oakville, Ontario, Canada - Oakville / Via Rail Service"));
        AIRPORTS.add(new Results("XPB", "Parksville, British Columbia, Canada - Parksville / Via Rail Service"));
        AIRPORTS.add(new Results("XPN", "Brampton, Ontario, Canada - Brampton / Via Rail Service"));
        AIRPORTS.add(new Results("XPX", "Pointe-Aux-Trembles, Quebec, Canada - Pointe Aux Trembles / Via Rail Service"));
        AIRPORTS.add(new Results("XQP", "Quepos, Costa Rica"));
        AIRPORTS.add(new Results("XQU", "Qualicum, British Columbia, Canada"));
        AIRPORTS.add(new Results("XRP", "Riviere-A-Pierre, Quebec, Canada - Riviere A Pierre / Via Rail Service"));
        AIRPORTS.add(new Results("XRY", "Jerez De La Frontera, Spain - La Parra"));
        AIRPORTS.add(new Results("XSC", "South Caicos, Turks And Caicos Islands"));
        AIRPORTS.add(new Results("XTY", "Strathroy, Ontario, Canada - Strathroy / Via Rail Service"));
        AIRPORTS.add(new Results("XVV", "Belleville, Ontario, Canada - Belleville / Via Rail Service"));
        AIRPORTS.add(new Results("XWY", "Wyoming, Ontario, Canada - Wyoming / Via Rail Service"));
        AIRPORTS.add(new Results("XZB", "Casselman, Ontario, Canada - Casselman / Via Rail Service"));
        AIRPORTS.add(new Results("XZC", "Glencoe, Ontario, Canada - Glencoe / Via Rail Service"));
        AIRPORTS.add(new Results("YAM", "Sault Ste Marie, Ontario, Canada - Sault Ste Marie Arpt"));
        AIRPORTS.add(new Results("YAP", "Yap, Caroline Islands, Micronesia"));
        AIRPORTS.add(new Results("YAZ", "Tofino, British Columbia, Canada - Tofino Airport"));
        AIRPORTS.add(new Results("YBA", "Banff, Alberta, Canada"));
        AIRPORTS.add(new Results("YBC", "Baie Comeau, Quebec, Canada"));
        AIRPORTS.add(new Results("YBL", "Campbell River /Campbell Rvr, British Columbia, Canada - Metropolitan Area"));
        AIRPORTS.add(new Results("YBR", "Brandon, Manitoba, Canada"));
        AIRPORTS.add(new Results("YBX", "Blanc Sablon, Quebec, Canada - Blanc Sablon Airport"));
        AIRPORTS.add(new Results("YCA", "Courtenay, British Columbia, Canada"));
        AIRPORTS.add(new Results("YCC", "Cornwall, Ontario, Canada - Regional"));
        AIRPORTS.add(new Results("YCD", "Nanaimo, British Columbia, Canada - Cassidy Airport"));
        AIRPORTS.add(new Results("YCG", "Castlegar, British Columbia, Canada"));
        AIRPORTS.add(new Results("YCM", "St Catharines, Ontario, Canada"));
        AIRPORTS.add(new Results("YCO", "Coppermine, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YDF", "Deer Lake, Newfoundland, Canada - Deer Lake"));
        AIRPORTS.add(new Results("YDN", "Dauphin, Manitoba, Canada"));
        AIRPORTS.add(new Results("YDQ", "Dawson Creek, British Columbia, Canada"));
        AIRPORTS.add(new Results("YEC", "Yechon, South Korea - Yechon"));
        AIRPORTS.add(new Results("YEG", "Edmonton, Alberta, Canada - Edmonton International"));
        AIRPORTS.add(new Results("YEL", "Elliot Lake, Ontario, Canada"));
        AIRPORTS.add(new Results("YEV", "Inuvik, Northwest Territories, Canada - Inuvik International Arpt"));
        AIRPORTS.add(new Results("YEY", "Amos, Quebec, Canada"));
        AIRPORTS.add(new Results("YFB", "Iqaluit, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YFC", "Fredericton, New Brunswick, Canada - Fredericton Municipal Apt"));
        AIRPORTS.add(new Results("YFS", "Fort Simpson, Northwest Territories, Canada - Fort Simpson Airport"));
        AIRPORTS.add(new Results("YGB", "Gillies Bay, British Columbia, Canada"));
        AIRPORTS.add(new Results("YGK", "Kingston, Ontario, Canada - Kingston Airport"));
        AIRPORTS.add(new Results("YGP", "Gaspe, Quebec, Canada"));
        AIRPORTS.add(new Results("YGR", "Iles De La Madeleine, Quebec, Canada - House Harbour Airport"));
        AIRPORTS.add(new Results("YGT", "Igloolik, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YGW", "Kuujjuarapik, Quebec, Canada - Kuujjuarapik"));
        AIRPORTS.add(new Results("YGX", "Gillam, Manitoba, Canada"));
        AIRPORTS.add(new Results("YHB", "Hudson Bay, Saskatchewan, Canada"));
        AIRPORTS.add(new Results("YHD", "Dryden, Ontario, Canada - Dryden Airport"));
        AIRPORTS.add(new Results("YHI", "Holman Island, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YHM", "Hamilton, Ontario, Canada - Hamilton Civic Airport"));
        AIRPORTS.add(new Results("YHN", "Hornepayne, Ontario, Canada"));
        AIRPORTS.add(new Results("YHY", "Hay River, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YHZ", "Halifax, Nova Scotia, Canada - Halifax International"));
        AIRPORTS.add(new Results("YIB", "Atikokan, Ontario, Canada"));
        AIRPORTS.add(new Results("YJA", "Jasper, Alberta, Canada"));
        AIRPORTS.add(new Results("YJT", "Stephenville, Newfoundland, Canada - Stephenville"));
        AIRPORTS.add(new Results("YKA", "Kamloops, British Columbia, Canada - Fulton Field"));
        AIRPORTS.add(new Results("YKF", "Kitchener, Ontario, Canada - Kitchener"));
        AIRPORTS.add(new Results("YKL", "Schefferville, Quebec, Canada - Schefferville"));
        AIRPORTS.add(new Results("YKM", "Yakima, WA, USA - Yakima Air Terminal"));
        AIRPORTS.add(new Results("YKQ", "Waskaganish, Quebec, Canada - Waskaganish"));
        AIRPORTS.add(new Results("YKS", "Yakutsk, Russia"));
        AIRPORTS.add(new Results("YLD", "Chapleau, Ontario, Canada"));
        AIRPORTS.add(new Results("YLQ", "La Tuque, Quebec, Canada - La Tuque"));
        AIRPORTS.add(new Results("YLW", "Kelowna, British Columbia, Canada - Ellison Field Airport"));
        AIRPORTS.add(new Results("YMM", "Fort Mcmurray, Alberta, Canada - Fort Mcmurray Municipal"));
        AIRPORTS.add(new Results("YMO", "Moosonee, Ontario, Canada - Moosonee"));
        AIRPORTS.add(new Results("YMT", "Chibougamau, Quebec, Canada - Chibougamau"));
        AIRPORTS.add(new Results("YMX", "Montreal, Quebec, Canada"));
        AIRPORTS.add(new Results("YND", "Gatineau, Quebec, Canada - Gatineau"));
        AIRPORTS.add(new Results("YNG", "Youngstown, OH, USA - Youngstown Municipal Airport"));
        AIRPORTS.add(new Results("YOJ", "High Level, Alberta, Canada - Footner Lake Muncpl"));
        AIRPORTS.add(new Results("YOO", "Oshawa, Ontario, Canada"));
        AIRPORTS.add(new Results("YOP", "Rainbow Lake, Alberta, Canada - Rainbow Lake"));
        AIRPORTS.add(new Results("YOW", "Ottawa, Ontario, Canada - Ottawa International"));
        AIRPORTS.add(new Results("YPE", "Peace River, Alberta, Canada - Peace River"));
        AIRPORTS.add(new Results("YPF", "Esquimalt, British Columbia, Canada"));
        AIRPORTS.add(new Results("YPR", "Prince Rupert /Princ Rupert, British Columbia, Canada - Digby Island"));
        AIRPORTS.add(new Results("YPW", "Powell River, British Columbia, Canada"));
        AIRPORTS.add(new Results("YPZ", "Burns Lake, British Columbia, Canada"));
        AIRPORTS.add(new Results("YQB", "Quebec, Quebec, Canada - Sainte Foy Airport"));
        AIRPORTS.add(new Results("YQC", "Quaqtaq, Quebec, Canada"));
        AIRPORTS.add(new Results("YQD", "The Pas, Manitoba, Canada - The Pas"));
        AIRPORTS.add(new Results("YQG", "Windsor, Ontario, Canada - Windsor International"));
        AIRPORTS.add(new Results("YQH", "Watson Lake, Yukon Territory, Canada - Watson Lake Airport"));
        AIRPORTS.add(new Results("YQI", "Yarmouth, Nova Scotia, Canada"));
        AIRPORTS.add(new Results("YQK", "Kenora, Ontario, Canada"));
        AIRPORTS.add(new Results("YQL", "Lethbridge, Alberta, Canada - Lethbridge Airport"));
        AIRPORTS.add(new Results("YQM", "Moncton, New Brunswick, Canada - Lakeburn Municipal Airpt"));
        AIRPORTS.add(new Results("YQQ", "Comox, British Columbia, Canada - Comox Civil Air Terminal"));
        AIRPORTS.add(new Results("YQR", "Regina, Saskatchewan, Canada - Regina International"));
        AIRPORTS.add(new Results("YQT", "Thunder Bay, Ontario, Canada"));
        AIRPORTS.add(new Results("YQU", "Grande Prairie, Alberta, Canada - Grande Prairie Airport"));
        AIRPORTS.add(new Results("YQX", "Gander, Newfoundland, Canada - Gander Intl Airport"));
        AIRPORTS.add(new Results("YQY", "Sydney, Nova Scotia, Canada - Sydney Municipal"));
        AIRPORTS.add(new Results("YQZ", "Quesnel, British Columbia, Canada"));
        AIRPORTS.add(new Results("YRB", "Resolute, Northwest Territories, Canada - Resolute Bay"));
        AIRPORTS.add(new Results("YRL", "Red Lake, Ontario, Canada"));
        AIRPORTS.add(new Results("YSB", "Sudbury, Ontario, Canada"));
        AIRPORTS.add(new Results("YSF", "Stony Rapids, Saskatchewan, Canada - Stony Rapids"));
        AIRPORTS.add(new Results("YSH", "Smith Falls, Ontario, Canada"));
        AIRPORTS.add(new Results("YSJ", "Saint John, New Brunswick, Canada - Turnbull Field"));
        AIRPORTS.add(new Results("YSL", "St Leonard, New Brunswick, Canada - St Leonard Apt"));
        AIRPORTS.add(new Results("YSM", "Fort Smith, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YSN", "Salmon Arm, British Columbia, Canada"));
        AIRPORTS.add(new Results("YSP", "Marathon, Ontario, Canada"));
        AIRPORTS.add(new Results("YTA", "Pembroke, Ontario, Canada - Pem And Area Apt"));
        AIRPORTS.add(new Results("YTD", "Thicket Portage, Manitoba, Canada"));
        AIRPORTS.add(new Results("YTH", "Thompson, Manitoba, Canada - Thompson"));
        AIRPORTS.add(new Results("YTS", "Timmins, Ontario, Canada - Timmins Municipal Airport"));
        AIRPORTS.add(new Results("YTZ", "Toronto, Ontario, Canada"));
        AIRPORTS.add(new Results("YUL", "Montreal, Quebec, Canada"));
        AIRPORTS.add(new Results("YUM", "Yuma, AZ, USA - Yuma International Airport"));
        AIRPORTS.add(new Results("YVA", "Moroni (Hahaya/Iconi)Comoros"));
        AIRPORTS.add(new Results("YVB", "Bonaventure, Quebec, Canada"));
        AIRPORTS.add(new Results("YVC", "La Ronge, Saskatchewan, Canada - La Ronge"));
        AIRPORTS.add(new Results("YVP", "Kuujjuaq, Quebec, Canada - Fort Chimo Airport"));
        AIRPORTS.add(new Results("YVR", "Vancouver, British Columbia, Canada - Vancouver International"));
        AIRPORTS.add(new Results("YVZ", "Deer Lake, Ontario, Canada"));
        AIRPORTS.add(new Results("YWG", "Winnipeg, Manitoba, Canada - Winnipeg International"));
        AIRPORTS.add(new Results("YWH", "Victoria, British Columbia, Canada - Victoria Inner Harbour"));
        AIRPORTS.add(new Results("YWK", "Wabush, Newfoundland, Canada - Wabush Municipal"));
        AIRPORTS.add(new Results("YWL", "Williams Lake, British Columbia, Canada"));
        AIRPORTS.add(new Results("YWR", "White River, Ontario, Canada - White River"));
        AIRPORTS.add(new Results("YXC", "Cranbrook, British Columbia, Canada - Cranbrook Airport"));
        AIRPORTS.add(new Results("YXD", "Edmonton, Alberta, Canada - Edmonton Municipal"));
        AIRPORTS.add(new Results("YXE", "Saskatoon, Saskatchewan, Canada - Saskatoon"));
        AIRPORTS.add(new Results("YXH", "Medicine Hat, Alberta, Canada - Medicine Hat Airport"));
        AIRPORTS.add(new Results("YXJ", "Fort St John, British Columbia, Canada - Fort St John"));
        AIRPORTS.add(new Results("YXL", "Sioux Lookout, Ontario, Canada"));
        AIRPORTS.add(new Results("YXS", "Prince George, British Columbia, Canada - Prince George B C"));
        AIRPORTS.add(new Results("YXT", "Terrace, British Columbia, Canada - Terrace"));
        AIRPORTS.add(new Results("YXU", "London, Ontario, Canada - London Municipal"));
        AIRPORTS.add(new Results("YXY", "Whitehorse, Yukon Territory, Canada - Whitehorse Airport"));
        AIRPORTS.add(new Results("YXZ", "Wawa, Ontario, Canada"));
        AIRPORTS.add(new Results("YYB", "North Bay, Ontario, Canada - Jack Garland Airport"));
        AIRPORTS.add(new Results("YYC", "Calgary, Alberta, Canada - Calgary Intl Airport"));
        AIRPORTS.add(new Results("YYD", "Smithers, British Columbia, Canada - Smithers International"));
        AIRPORTS.add(new Results("YYF", "Penticton, British Columbia, Canada"));
        AIRPORTS.add(new Results("YYG", "Charlottetown, Prince Edward Island/, Canada - Charlottetown"));
        AIRPORTS.add(new Results("YYJ", "Victoria, British Columbia, Canada - Victoria Airport"));
        AIRPORTS.add(new Results("YYQ", "Churchill, Manitoba, Canada - Churchill Airport"));
        AIRPORTS.add(new Results("YYR", "Goose Bay, Newfoundland, Canada - Goose Bay Municipal Airpt"));
        AIRPORTS.add(new Results("YYT", "St Johns, Newfoundland, Canada - St John's International"));
        AIRPORTS.add(new Results("YYU", "Kapuskasing, Ontario, Canada"));
        AIRPORTS.add(new Results("YYY", "Mont Joli, Quebec, Canada"));
        AIRPORTS.add(new Results("YYZ", "Toronto, Ontario, Canada - Pearson International Airport"));
        AIRPORTS.add(new Results("YZF", "Yellowknife, Northwest Territories, Canada"));
        AIRPORTS.add(new Results("YZT", "Port Hardy, British Columbia, Canada - Port Hardy Airport"));
        AIRPORTS.add(new Results("YZV", "Sept-Iles, Quebec, Canada"));
        AIRPORTS.add(new Results("ZAG", "Zagreb, Croatia (Hrvatska) - Zagreb"));
        AIRPORTS.add(new Results("ZAH", "Zahedan, Iran - Zahedan"));
        AIRPORTS.add(new Results("ZAL", "Valdivia, Chile - Pichoy"));
        AIRPORTS.add(new Results("ZAM", "Zamboanga, Philippines - Zamboanga Airport"));
        AIRPORTS.add(new Results("ZAZ", "Zaragoza, Spain - Zaragoza"));
        AIRPORTS.add(new Results("ZBV", "Vail/Eagle, CO, USA"));
        AIRPORTS.add(new Results("ZCL", "Zacatecas, Zacatecas, Mexico"));
        AIRPORTS.add(new Results("ZCO", "Temuco, Chile - Manquehue"));
        AIRPORTS.add(new Results("ZDJ", "Berne, Switzerland - Berne-Rr Station"));
        AIRPORTS.add(new Results("ZGI", "Gods River, Manitoba, Canada"));
        AIRPORTS.add(new Results("ZHA", "Zhanjiang, China"));
        AIRPORTS.add(new Results("ZHO", "Houston, British Columbia, Canada"));
        AIRPORTS.add(new Results("ZIH", "Ixtapa/Zihuatanejo, Guerrero, Mexico - International"));
        AIRPORTS.add(new Results("ZLO", "Manzanillo, Colima, Mexico - Aeropuerto International"));
        AIRPORTS.add(new Results("ZNA", "Nanaimo, British Columbia, Canada"));
        AIRPORTS.add(new Results("ZNE", "Newman, Western Australia, Australia - Newman"));
        AIRPORTS.add(new Results("ZNZ", "Zanzibar, Tanzania - Kisauni"));
        AIRPORTS.add(new Results("ZQN", "Queenstown, New Zealand - Frankton"));
        AIRPORTS.add(new Results("ZRF", "Rockford, IL, USA"));
        AIRPORTS.add(new Results("ZRH", "Zurich, Switzerland - Zurich"));
        AIRPORTS.add(new Results("ZSA", "San Salvador, Bahamas"));
        AIRPORTS.add(new Results("ZTH", "Zakinthos, Greece - Zakinthos"));
    }
}
